@@ -1,6 +1,6 @@
 /* airpcap_loader.c
  *
- * $Id: airpcap_loader.c 26941 2008-12-08 23:46:26Z stig $
+ * $Id: airpcap_loader.c 28352 2009-05-13 17:29:13Z jmayer $
  *
  * Giorgio Tino <giorgio.tino@cacetech.com>
  * Copyright (c) CACE Technologies, LLC 2006
@@ -24,7 +24,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifdef _WIN32
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
@@ -55,27 +54,20 @@
 #include "airpcap_loader.h"
 
 
-/*
- * We load dynamically the dag library in order link it only when
- * it's present on the system
- */
-static HMODULE AirpcapLib = NULL;
-
 /*
  * Set to TRUE if the DLL was successfully loaded AND all functions
  * are present.
  */
 static gboolean AirpcapLoaded = FALSE;
 
-static int AirpcapVersion = 3;
+#ifdef _WIN32
+/*
+ * We load dynamically the dag library in order link it only when
+ * it's present on the system
+ */
+static void * AirpcapLib = NULL;
 
 static AirpcapGetLastErrorHandler g_PAirpcapGetLastError;
-static AirpcapGetDeviceListHandler g_PAirpcapGetDeviceList;
-static AirpcapFreeDeviceListHandler g_PAirpcapFreeDeviceList;
-static AirpcapOpenHandler g_PAirpcapOpen;
-static AirpcapCloseHandler g_PAirpcapClose;
-static AirpcapGetLinkTypeHandler g_PAirpcapGetLinkType;
-static AirpcapSetLinkTypeHandler g_PAirpcapSetLinkType;
 static AirpcapSetKernelBufferHandler g_PAirpcapSetKernelBuffer;
 static AirpcapSetFilterHandler g_PAirpcapSetFilter;
 static AirpcapGetMacAddressHandler g_PAirpcapGetMacAddress;
@@ -83,6 +75,16 @@ static AirpcapSetMinToCopyHandler g_PAirpcapSetMinToCopy;
 static AirpcapGetReadEventHandler g_PAirpcapGetReadEvent;
 static AirpcapReadHandler g_PAirpcapRead;
 static AirpcapGetStatsHandler g_PAirpcapGetStats;
+#endif
+
+static int AirpcapVersion = 3;
+
+static AirpcapGetDeviceListHandler g_PAirpcapGetDeviceList;
+static AirpcapFreeDeviceListHandler g_PAirpcapFreeDeviceList;
+static AirpcapOpenHandler g_PAirpcapOpen;
+static AirpcapCloseHandler g_PAirpcapClose;
+static AirpcapGetLinkTypeHandler g_PAirpcapGetLinkType;
+static AirpcapSetLinkTypeHandler g_PAirpcapSetLinkType;
 static AirpcapTurnLedOnHandler g_PAirpcapTurnLedOn;
 static AirpcapTurnLedOffHandler g_PAirpcapTurnLedOff;
 static AirpcapGetDeviceChannelHandler g_PAirpcapGetDeviceChannel;
@@ -118,7 +120,7 @@ airpcap_if_info_t *airpcap_if_active = NULL;
 module_t *wlan_prefs = NULL;
 
 Dot11Channel *pSupportedChannels;
-ULONG numSupportedChannels;
+guint32 numSupportedChannels;
 
 static AirpcapChannelInfo LegacyChannels[] =
 {
@@ -138,7 +140,7 @@ static AirpcapChannelInfo LegacyChannels[] =
 	{2484, 0, {0,0,0}},
 };
 
-static ULONG num_legacy_channels = 14;
+static guint32 num_legacy_channels = 14;
 
 /*
  * Callback used by the load_wlan_keys() routine in order to read a WEP decryption key
@@ -262,12 +264,11 @@ set_wep_key(pref_t *pref, gpointer ud _U_)
  * Function used to read the Decryption Keys from the preferences and store them
  * properly into the airpcap adapter.
  */
-BOOL
-load_wlan_driver_wep_keys()
+gboolean
+load_wlan_driver_wep_keys(void)
 {
     keys_cb_data_t* user_data;
     guint i;
-    gchar *tmp = NULL;
 
     /* Retrieve the wlan preferences */
     wlan_prefs = prefs_find_module("wlan");
@@ -317,16 +318,16 @@ load_wlan_driver_wep_keys()
  * This function will tell the airpcap driver the key list to use
  * This will be stored into the registry...
  */
-BOOL
+gboolean
 write_wlan_wep_keys_to_registry(airpcap_if_info_t* info_if, GList* key_list)
 {
-    UINT i,j;
+    guint i,j;
     GString *new_key;
     gchar s[3];
     PAirpcapKeysCollection KeysCollection;
-    ULONG KeysCollectionSize;
-    UCHAR KeyByte;
-    UINT keys_in_list = 0;
+    guint32 KeysCollectionSize;
+    guint8 KeyByte;
+    guint keys_in_list = 0;
     decryption_key_t* key_item = NULL;
 
     keys_in_list = g_list_length(key_list);
@@ -371,7 +372,7 @@ write_wlan_wep_keys_to_registry(airpcap_if_info_t* info_if, GList* key_list)
 	    s[0] = new_key->str[j];
 	    s[1] = new_key->str[j+1];
 	    s[2] = '\0';
-	    KeyByte = (UCHAR)strtol(s, NULL, 16);
+	    KeyByte = (guint8)strtol(s, NULL, 16);
 	    KeysCollection->Keys[i].KeyData[j / 2] = KeyByte;
 	}
 
@@ -407,16 +408,16 @@ write_wlan_wep_keys_to_registry(airpcap_if_info_t* info_if, GList* key_list)
  * This function will tell the airpcap driver the key list to use
  * This will be stored into the registry...
  */
-BOOL
+gboolean
 write_wlan_driver_wep_keys_to_registry(GList* key_list)
 {
-    UINT i,j,k,n,y;
+    guint i,j,k,n,y;
     GString *new_key;
     gchar s[3];
     PAirpcapKeysCollection KeysCollection;
-    ULONG KeysCollectionSize;
-    UCHAR KeyByte;
-    UINT keys_in_list = 0;
+    guint32 KeysCollectionSize;
+    guint8 KeyByte;
+    guint keys_in_list = 0;
     decryption_key_t* key_item = NULL;
     airpcap_if_info_t* fake_info_if = NULL;
 
@@ -492,7 +493,7 @@ write_wlan_driver_wep_keys_to_registry(GList* key_list)
 		s[0] = new_key->str[j];
 		s[1] = new_key->str[j+1];
 		s[2] = '\0';
-		KeyByte = (UCHAR)strtol(s, NULL, 16);
+		KeyByte = (guint8)strtol(s, NULL, 16);
 		KeysCollection->Keys[y].KeyData[j / 2] = KeyByte;
 	    }
 	    /* XXX - Change when WPA will be supported!!! */
@@ -540,7 +541,7 @@ write_wlan_driver_wep_keys_to_registry(GList* key_list)
  *  Function used to save to the preference file the Decryption Keys.
  */
 int
-save_wlan_driver_wep_keys()
+save_wlan_driver_wep_keys(void)
 {
     GList* key_list = NULL;
     char* tmp_key = NULL;
@@ -623,10 +624,8 @@ int
 save_wlan_wireshark_wep_keys(GList* key_ls)
 {
     GList* key_list = NULL;
-    char* tmp_key = NULL;
     guint keys_in_list,i;
     keys_cb_data_t* user_data;
-    airpcap_if_info_t* fake_info_if = NULL;
     decryption_key_t* tmp_dk;
 
     /* Retrieve the wlan preferences */
@@ -688,7 +687,7 @@ cant_get_airpcap_if_list_error_message(const char *err_str)
 /*
  * Airpcap wrapper, used to store the current settings for the selected adapter
  */
-BOOL
+gboolean
 airpcap_if_store_cur_config_as_adapter_default(PAirpcapHandle ah)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -699,7 +698,7 @@ airpcap_if_store_cur_config_as_adapter_default(PAirpcapHandle ah)
  * Airpcap wrapper, used to open an airpcap adapter
  */
 PAirpcapHandle
-airpcap_if_open(PCHAR name, PCHAR err)
+airpcap_if_open(gchar * name, gchar * err)
 {
     if (!AirpcapLoaded) return NULL;
     if (name == NULL) return NULL;
@@ -709,7 +708,7 @@ airpcap_if_open(PCHAR name, PCHAR err)
 /*
  * Airpcap wrapper, used to close an airpcap adapter
  */
-VOID
+void
 airpcap_if_close(PAirpcapHandle handle)
 {
     if (!AirpcapLoaded) return;
@@ -720,7 +719,7 @@ airpcap_if_close(PAirpcapHandle handle)
  * Retrieve the state of the Airpcap DLL
  */
 int
-airpcap_get_dll_state()
+airpcap_get_dll_state(void)
 {
   return AirpcapVersion;
 }
@@ -728,8 +727,8 @@ airpcap_get_dll_state()
 /*
  * Airpcap wrapper, used to turn on the led of an airpcap adapter
  */
-BOOL
-airpcap_if_turn_led_on(PAirpcapHandle AdapterHandle, UINT LedNumber)
+gboolean
+airpcap_if_turn_led_on(PAirpcapHandle AdapterHandle, guint LedNumber)
 {
     if (!AirpcapLoaded) return FALSE;
     return g_PAirpcapTurnLedOn(AdapterHandle,LedNumber);
@@ -738,8 +737,8 @@ airpcap_if_turn_led_on(PAirpcapHandle AdapterHandle, UINT LedNumber)
 /*
  * Airpcap wrapper, used to turn off the led of an airpcap adapter
  */
-BOOL
-airpcap_if_turn_led_off(PAirpcapHandle AdapterHandle, UINT LedNumber)
+gboolean
+airpcap_if_turn_led_off(PAirpcapHandle AdapterHandle, guint LedNumber)
 {
     if (!AirpcapLoaded) return FALSE;
     return g_PAirpcapTurnLedOff(AdapterHandle,LedNumber);
@@ -748,8 +747,8 @@ airpcap_if_turn_led_off(PAirpcapHandle AdapterHandle, UINT LedNumber)
 /*
  * Airpcap wrapper, used to get the channel of an airpcap adapter
  */
-BOOL
-airpcap_if_get_device_channel(PAirpcapHandle ah, PUINT ch)
+gboolean
+airpcap_if_get_device_channel(PAirpcapHandle ah, guint * ch)
 {
     if (!AirpcapLoaded) return FALSE;
     return g_PAirpcapGetDeviceChannel(ah,ch);
@@ -758,8 +757,8 @@ airpcap_if_get_device_channel(PAirpcapHandle ah, PUINT ch)
 /*
  * Airpcap wrapper, used to get the supported channels of an airpcap adapter
  */
-BOOL
-airpcap_if_get_device_supported_channels(PAirpcapHandle ah, AirpcapChannelInfo **cInfo, PULONG nInfo)
+gboolean
+airpcap_if_get_device_supported_channels(PAirpcapHandle ah, AirpcapChannelInfo **cInfo, guint32 * nInfo)
 {
     if (!AirpcapLoaded) return FALSE;
     if (airpcap_get_dll_state() == AIRPCAP_DLL_OLD){
@@ -777,10 +776,10 @@ airpcap_if_get_device_supported_channels(PAirpcapHandle ah, AirpcapChannelInfo *
  * Airpcap wrapper, used to get the supported channels of an airpcap adapter
  */
 Dot11Channel*
-airpcap_if_get_device_supported_channels_array(PAirpcapHandle ah, PULONG pNumSupportedChannels)
+airpcap_if_get_device_supported_channels_array(PAirpcapHandle ah, guint32 * pNumSupportedChannels)
 {
     AirpcapChannelInfo *chanInfo;
-    ULONG i=0, j=0, numInfo = 0;
+    guint32 i=0, j=0, numInfo = 0;
 
     if (!AirpcapLoaded)
         return NULL;
@@ -794,11 +793,11 @@ airpcap_if_get_device_supported_channels_array(PAirpcapHandle ah, PULONG pNumSup
     if (numInfo == 0)
         return NULL;
 
-    pSupportedChannels = malloc(numInfo * (sizeof *pSupportedChannels));
+    pSupportedChannels = g_malloc(numInfo * (sizeof *pSupportedChannels));
 
     for (i = 0; i < numInfo; i++)
     {
-        ULONG supportedChannel = 0xFFFFFFFF;
+        guint32 supportedChannel = 0xFFFFFFFF;
 
         /*
          * search if we have it already
@@ -822,10 +821,10 @@ airpcap_if_get_device_supported_channels_array(PAirpcapHandle ah, PULONG pNumSup
             switch(chanInfo[i].ExtChannel)
             {
                 case -1:
-                    pSupportedChannels[numSupportedChannels].Flags = FLAG_CAN_BE_HIGH;
+                    pSupportedChannels[numSupportedChannels].Flags = FLAG_CAN_BE_LOW;
                     break;
                 case +1:
-                    pSupportedChannels[numSupportedChannels].Flags = FLAG_CAN_BE_LOW;
+                    pSupportedChannels[numSupportedChannels].Flags = FLAG_CAN_BE_HIGH;
                     break;
                 case 0:
                 default:
@@ -851,10 +850,10 @@ airpcap_if_get_device_supported_channels_array(PAirpcapHandle ah, PULONG pNumSup
             switch(chanInfo[i].ExtChannel)
             {
                 case -1:
-                    pSupportedChannels[supportedChannel].Flags |= FLAG_CAN_BE_HIGH;
+                    pSupportedChannels[supportedChannel].Flags |= FLAG_CAN_BE_LOW;
                     break;
                 case +1:
-                    pSupportedChannels[supportedChannel].Flags |= FLAG_CAN_BE_LOW;
+                    pSupportedChannels[supportedChannel].Flags |= FLAG_CAN_BE_HIGH;
                     break;
                 case 0:
                 default:
@@ -888,8 +887,8 @@ airpcap_if_get_device_supported_channels_array(PAirpcapHandle ah, PULONG pNumSup
 /*
  * Airpcap wrapper, used to set the channel of an airpcap adapter
  */
-BOOL
-airpcap_if_set_device_channel(PAirpcapHandle ah, UINT ch)
+gboolean
+airpcap_if_set_device_channel(PAirpcapHandle ah, guint ch)
 {
     if (!AirpcapLoaded) return FALSE;
     return g_PAirpcapSetDeviceChannel(ah,ch);
@@ -898,12 +897,12 @@ airpcap_if_set_device_channel(PAirpcapHandle ah, UINT ch)
 /*
  * Airpcap wrapper, used to set the frequency of an airpcap adapter
  */
-BOOL
+gboolean
 airpcap_if_set_device_channel_ex(PAirpcapHandle ah, AirpcapChannelInfo ChannelInfo)
 {
     if (!AirpcapLoaded) return FALSE;
     if (airpcap_get_dll_state() == AIRPCAP_DLL_OLD){
-      guint channel = 0;
+      gint channel = 0;
       channel = ieee80211_mhz_to_chan(ChannelInfo.Frequency);
 
       if (channel < 0){
@@ -921,7 +920,7 @@ airpcap_if_set_device_channel_ex(PAirpcapHandle ah, AirpcapChannelInfo ChannelIn
 /*
  * Airpcap wrapper, used to get the frequency of an airpcap adapter
  */
-BOOL
+gboolean
 airpcap_if_get_device_channel_ex(PAirpcapHandle ah, PAirpcapChannelInfo pChannelInfo)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -934,7 +933,7 @@ airpcap_if_get_device_channel_ex(PAirpcapHandle ah, PAirpcapChannelInfo pChannel
 
     if (airpcap_get_dll_state() == AIRPCAP_DLL_OLD){
       guint channel = 0;
-      ULONG chan_freq = 0;
+      guint32 chan_freq = 0;
 
       if (!airpcap_if_get_device_channel(ah, &channel)) return FALSE;
 
@@ -952,7 +951,7 @@ airpcap_if_get_device_channel_ex(PAirpcapHandle ah, PAirpcapChannelInfo pChannel
 /*
  * Airpcap wrapper, used to get the link type of an airpcap adapter
  */
-BOOL
+gboolean
 airpcap_if_get_link_type(PAirpcapHandle ah, PAirpcapLinkType lt)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -962,7 +961,7 @@ airpcap_if_get_link_type(PAirpcapHandle ah, PAirpcapLinkType lt)
 /*
  * Airpcap wrapper, used to set the link type of an airpcap adapter
  */
-BOOL
+gboolean
 airpcap_if_set_link_type(PAirpcapHandle ah, AirpcapLinkType lt)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -972,8 +971,8 @@ airpcap_if_set_link_type(PAirpcapHandle ah, AirpcapLinkType lt)
 /*
  * Airpcap wrapper, used to get the fcs presence of an airpcap adapter
  */
-BOOL
-airpcap_if_get_fcs_presence(PAirpcapHandle ah, PBOOL fcs)
+gboolean
+airpcap_if_get_fcs_presence(PAirpcapHandle ah, gboolean * fcs)
 {
     if (!AirpcapLoaded) return FALSE;
     return g_PAirpcapGetFcsPresence(ah,fcs);
@@ -982,8 +981,8 @@ airpcap_if_get_fcs_presence(PAirpcapHandle ah, PBOOL fcs)
 /*
  * Airpcap wrapper, used to set the fcs presence of an airpcap adapter
  */
-BOOL
-airpcap_if_set_fcs_presence(PAirpcapHandle ah, BOOL fcs)
+gboolean
+airpcap_if_set_fcs_presence(PAirpcapHandle ah, gboolean fcs)
 {
     if (!AirpcapLoaded) return FALSE;
     return g_PAirpcapSetFcsPresence(ah,fcs);
@@ -992,7 +991,7 @@ airpcap_if_set_fcs_presence(PAirpcapHandle ah, BOOL fcs)
 /*
  * Airpcap wrapper, used to get the decryption enabling of an airpcap adapter
  */
-BOOL
+gboolean
 airpcap_if_get_decryption_state(PAirpcapHandle ah, PAirpcapDecryptionState PEnable)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -1002,7 +1001,7 @@ airpcap_if_get_decryption_state(PAirpcapHandle ah, PAirpcapDecryptionState PEnab
 /*
  * Airpcap wrapper, used to set the decryption enabling of an airpcap adapter
  */
-BOOL
+gboolean
 airpcap_if_set_decryption_state(PAirpcapHandle ah, AirpcapDecryptionState Enable)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -1012,7 +1011,7 @@ airpcap_if_set_decryption_state(PAirpcapHandle ah, AirpcapDecryptionState Enable
 /*
  * Airpcap wrapper, used to get the decryption enabling of an airpcap driver
  */
-BOOL
+gboolean
 airpcap_if_get_driver_decryption_state(PAirpcapHandle ah, PAirpcapDecryptionState PEnable)
 {
     if (!AirpcapLoaded || (g_PAirpcapGetDriverDecryptionState==NULL)) return FALSE;
@@ -1022,7 +1021,7 @@ airpcap_if_get_driver_decryption_state(PAirpcapHandle ah, PAirpcapDecryptionStat
 /*
  * Airpcap wrapper, used to set the decryption enabling of an airpcap driver
  */
-BOOL
+gboolean
 airpcap_if_set_driver_decryption_state(PAirpcapHandle ah, AirpcapDecryptionState Enable)
 {
     if (!AirpcapLoaded || (g_PAirpcapSetDriverDecryptionState==NULL)) return FALSE;
@@ -1032,7 +1031,7 @@ airpcap_if_set_driver_decryption_state(PAirpcapHandle ah, AirpcapDecryptionState
 /*
  * Airpcap wrapper, used to get the fcs validation of an airpcap adapter
  */
-BOOL
+gboolean
 airpcap_if_get_fcs_validation(PAirpcapHandle ah, PAirpcapValidationType val)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -1042,7 +1041,7 @@ airpcap_if_get_fcs_validation(PAirpcapHandle ah, PAirpcapValidationType val)
 /*
  * Airpcap wrapper, used to set the fcs validation of an airpcap adapter
  */
-BOOL
+gboolean
 airpcap_if_set_fcs_validation(PAirpcapHandle ah, AirpcapValidationType val)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -1052,7 +1051,7 @@ airpcap_if_set_fcs_validation(PAirpcapHandle ah, AirpcapValidationType val)
 /*
  * Airpcap wrapper, used to save the settings for the selected_if
  */
-BOOL
+gboolean
 airpcap_if_set_device_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection KeysCollection)
 {
     if (!AirpcapLoaded) return FALSE;
@@ -1062,8 +1061,8 @@ airpcap_if_set_device_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection
 /*
  * Airpcap wrapper, used to save the settings for the selected_if
  */
-BOOL
-airpcap_if_get_device_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection KeysCollection, PUINT PKeysCollectionSize)
+gboolean
+airpcap_if_get_device_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection KeysCollection, guint * PKeysCollectionSize)
 {
     if (!AirpcapLoaded) return FALSE;
     return g_PAirpcapGetDeviceKeys(AdapterHandle,KeysCollection,PKeysCollectionSize);
@@ -1072,7 +1071,7 @@ airpcap_if_get_device_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection
 /*
  * Airpcap wrapper, used to save the driver's set of keys
  */
-BOOL
+gboolean
 airpcap_if_set_driver_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection KeysCollection)
 {
     if (!AirpcapLoaded || (g_PAirpcapSetDriverKeys==NULL)) return FALSE;
@@ -1082,8 +1081,8 @@ airpcap_if_set_driver_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection
 /*
  * Airpcap wrapper, used to load the driver's set of keys
  */
-BOOL
-airpcap_if_get_driver_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection KeysCollection, PUINT PKeysCollectionSize)
+gboolean
+airpcap_if_get_driver_keys(PAirpcapHandle AdapterHandle, PAirpcapKeysCollection KeysCollection, guint * PKeysCollectionSize)
 {
     if (!AirpcapLoaded || (g_PAirpcapGetDriverKeys==NULL)) return FALSE;
     return g_PAirpcapGetDriverKeys(AdapterHandle,KeysCollection,PKeysCollectionSize);
@@ -1138,7 +1137,7 @@ airpcap_if_info_new(char *name, char *description)
  * This function will create a new fake drivers' interface, to load global keys...
  */
 airpcap_if_info_t*
-airpcap_driver_fake_if_info_new()
+airpcap_driver_fake_if_info_new(void)
 {
     PAirpcapHandle ad;
     gchar ebuf[AIRPCAP_ERRBUF_SIZE];
@@ -1216,14 +1215,14 @@ airpcap_if_info_print(airpcap_if_info_t* if_info)
     g_print("                  LINKTYPE: %d\n",if_info->linkType);
     g_print("                  LOOPBACK: %s\n",if_info->loopback ? "YES" : "NO");
     g_print("                 (GTK) TAG: %d\n",if_info->tag);
-    g_print("SUPPORTED CHANNELS POINTER: %lu\n",if_info->pSupportedChannels);
-    g_print("    NUM SUPPORTED CHANNELS: %lu\n",if_info->numSupportedChannels);
+    g_print("SUPPORTED CHANNELS POINTER: %p\n",if_info->pSupportedChannels);
+    g_print("    NUM SUPPORTED CHANNELS: %u\n",if_info->numSupportedChannels);
 
     for(i=0; i<(if_info->numSupportedChannels); i++){
       g_print("\n        SUPPORTED CHANNEL #%u\n",i+1);
       g_print("                   CHANNEL: %u\n",if_info->pSupportedChannels[i].Channel);
-      g_print("                 FREQUENCY: %lu\n",if_info->pSupportedChannels[i].Frequency);
-      g_print("                     FLAGS: %lu\n",if_info->pSupportedChannels[i].Flags);
+      g_print("                 FREQUENCY: %u\n",if_info->pSupportedChannels[i].Frequency);
+      g_print("                     FLAGS: %u\n",if_info->pSupportedChannels[i].Flags);
     }
     g_print("\n\n");
 }
@@ -1231,7 +1230,7 @@ airpcap_if_info_print(airpcap_if_info_t* if_info)
 /*
  * Function used to load the WEP keys for a selected interface
  */
-BOOL
+gboolean
 airpcap_if_load_keys(PAirpcapHandle ad, airpcap_if_info_t *if_info)
 {
     if(!if_info) return FALSE;
@@ -1268,7 +1267,7 @@ airpcap_if_load_keys(PAirpcapHandle ad, airpcap_if_info_t *if_info)
 /*
  * Function used to load the WEP keys for a selected interface
  */
-BOOL
+gboolean
 airpcap_if_load_driver_keys(PAirpcapHandle ad, airpcap_if_info_t *if_info)
 {
     if_info->keysCollectionSize = 0;
@@ -1491,7 +1490,7 @@ airpcap_get_key_string(AirpcapKey key)
 
 	    for(j = 0; j < key.KeyLen; j++)
 	    {
-		src = g_strdup_printf("%.2x\0", key.KeyData[j]);
+		src = g_strdup_printf("%.2x", key.KeyData[j]);
 		/*
 		 * XXX - use g_strconcat() or GStrings instead ???
 		 */
@@ -1561,7 +1560,7 @@ airpcap_get_if_string_number(airpcap_if_info_t* if_info)
     }
     else
     {
-	number = g_strdup_printf("%.2u\0",n);
+	number = g_strdup_printf("%.2u",n);
     }
 
     return number;
@@ -1593,10 +1592,6 @@ airpcap_get_if_string_number_from_description(gchar* description)
 airpcap_if_info_t*
 airpcap_get_default_if(GList* airpcap_if_list)
 {
-    int ifn = 0;
-    GList* popdown_if_list = NULL;
-    GList* curr = NULL;
-
     gchar* s;
     airpcap_if_info_t* if_info = NULL;
 
@@ -1842,7 +1837,7 @@ get_airpcap_device_keys(airpcap_if_info_t* info_if)
  * keys for the global AirPcap driver... returns NULL if no keys are found.
  */
 GList*
-get_airpcap_driver_keys()
+get_airpcap_driver_keys(void)
 {
     /* tmp vars */
     char* tmp_key = NULL;
@@ -1916,12 +1911,10 @@ get_airpcap_driver_keys()
  * no key is found
  */
 GList*
-get_wireshark_keys()
+get_wireshark_keys(void)
 {
     keys_cb_data_t* wep_user_data = NULL;
 
-    gchar *tmp = NULL;
-
     GList* final_list = NULL;
     GList* wep_final_list = NULL;
 
@@ -2258,7 +2251,7 @@ test_if_on(pref_t *pref, gpointer ud)
  * Returns TRUE if the Wireshark decryption is active, false otherwise
  */
 gboolean
-wireshark_decryption_on()
+wireshark_decryption_on(void)
 {
     gboolean is_on;
 
@@ -2275,7 +2268,7 @@ wireshark_decryption_on()
  * Returns TRUE if the AirPcap decryption for the current adapter is active, false otherwise
  */
 gboolean
-airpcap_decryption_on()
+airpcap_decryption_on(void)
 {
     gboolean is_on = FALSE;
 
@@ -2454,8 +2447,9 @@ set_airpcap_decryption(gboolean on_off)
  */
 int load_airpcap(void)
 {
-    BOOL base_functions = TRUE;
-    BOOL eleven_n_functions = TRUE;
+#ifdef _WIN32
+    gboolean base_functions = TRUE;
+    gboolean eleven_n_functions = TRUE;
 
     if((AirpcapLib =  LoadLibrary(TEXT("airpcap.dll"))) == NULL)
     {
@@ -2516,6 +2510,9 @@ int load_airpcap(void)
   		}
     }
     return AirpcapVersion;
+#else /* _WIN32 */
+    return AIRPCAP_DLL_NOT_FOUND;
+#endif /* _WIN32 */
 }
 
 /*
@@ -2546,4 +2543,3 @@ get_runtime_airpcap_version(GString *str)
 	vrev, build);
 }
 #endif /* HAVE_AIRPCAP */
-#endif /* _WIN32 */
