@@ -2,7 +2,7 @@
  * Routines for h225 packet dissection
  * Copyright 2005, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-h225-template.c 25335 2008-05-21 05:41:39Z etxrab $
+ * $Id: packet-h225-template.c 29662 2009-09-01 22:36:30Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -77,8 +77,6 @@ static h225_packet_info pi_arr[5]; /* We assuming a maximum of 5 H225 messaages
 static int pi_current=0;
 h225_packet_info *h225_pi=&pi_arr[0];
 
-static dissector_handle_t h225ras_handle;
-static dissector_handle_t H323UserInformation_handle;
 static dissector_handle_t data_handle;
 /* Subdissector tables */
 static dissector_table_t nsp_object_dissector_table;
@@ -121,12 +119,12 @@ static gboolean h225_h245_in_tree = TRUE;
 static gboolean h225_tp_in_tree = TRUE;
 
 /* Global variables */
-static guint saved_h225_tls_port;
 static guint32  ipv4_address;
 static guint32  ipv4_port;
 guint32 T38_manufacturer_code;
 guint32 value;
 static gboolean contains_faststart = FALSE;
+static e_guid_t *call_id_guid;
 
 /* NonStandardParameter */
 static const char *nsiOID;
@@ -151,15 +149,15 @@ dissect_h225_H323UserInformation(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 	proto_tree *tr;
 	int offset = 0;
 
-    pi_current++;
-    if(pi_current==5){
-      pi_current=0;
-    }
-    h225_pi=&pi_arr[pi_current];
+	pi_current++;
+	if(pi_current==5){
+		pi_current=0;
+	}
+	h225_pi=&pi_arr[pi_current];
 
 	/* Init struct for collecting h225_packet_info */
-    reset_h225_packet_info(h225_pi);
-    h225_pi->msg_type = H225_CS;
+	reset_h225_packet_info(h225_pi);
+	h225_pi->msg_type = H225_CS;
 
 	next_tvb_init(&h245_list);
 	next_tvb_init(&tp_list);
@@ -194,15 +192,15 @@ dissect_h225_h225_RasMessage(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 	proto_tree *tr;
 	guint32 offset=0;
 
-    pi_current++;
-    if(pi_current==5){
-        pi_current=0;
-    }
-    h225_pi=&pi_arr[pi_current];
+	pi_current++;
+	if(pi_current==5){
+		pi_current=0;
+	}
+	h225_pi=&pi_arr[pi_current];
 
 	/* Init struct for collecting h225_packet_info */
-    reset_h225_packet_info(h225_pi);
-    h225_pi->msg_type = H225_RAS;
+	reset_h225_packet_info(h225_pi);
+	h225_pi->msg_type = H225_RAS;
 
 	if (check_col(pinfo->cinfo, COL_PROTOCOL)){
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, PSNAME);
@@ -304,27 +302,25 @@ void
 proto_reg_handoff_h225(void)
 {
 	static gboolean h225_prefs_initialized = FALSE;
+	static dissector_handle_t h225ras_handle;
+	static guint saved_h225_tls_port;
 
-    if (h225_prefs_initialized) {
-      ssl_dissector_delete(saved_h225_tls_port, "q931.tpkt", TRUE);
-    } else {
-      h225_prefs_initialized = TRUE;
-    }
+	if (!h225_prefs_initialized) {
+		h225ras_handle=find_dissector("h225.ras");
+		dissector_add("udp.port", UDP_PORT_RAS1, h225ras_handle);
+		dissector_add("udp.port", UDP_PORT_RAS2, h225ras_handle);
 
-    saved_h225_tls_port = h225_tls_port;
-    ssl_dissector_add(saved_h225_tls_port, "q931.tpkt", TRUE);
-
-	h225ras_handle=new_create_dissector_handle(dissect_h225_h225_RasMessage, proto_h225);
-	dissector_add("udp.port", UDP_PORT_RAS1, h225ras_handle);
-	dissector_add("udp.port", UDP_PORT_RAS2, h225ras_handle);
-
-	H323UserInformation_handle=find_dissector("h323ui");
-
-	h245_handle = find_dissector("h245");
-	h245dg_handle = find_dissector("h245dg");
-	h4501_handle = find_dissector("h4501");
-	data_handle = find_dissector("data");
+		h245_handle = find_dissector("h245");
+		h245dg_handle = find_dissector("h245dg");
+		h4501_handle = find_dissector("h4501");
+		data_handle = find_dissector("data");
+		h225_prefs_initialized = TRUE;
+	} else {
+		ssl_dissector_delete(saved_h225_tls_port, "q931.tpkt", TRUE);
+	}
 
+	saved_h225_tls_port = h225_tls_port;
+	ssl_dissector_add(saved_h225_tls_port, "q931.tpkt", TRUE);
 }
 
 
@@ -457,7 +453,7 @@ static void ras_call_matching(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 			}
 
 			/* add link to response frame, if available */
-			if(h225ras_call->rsp_num != 0){
+			if(h225ras_call && h225ras_call->rsp_num != 0){
 				proto_item *ti =
 				proto_tree_add_uint_format(tree, hf_h225_ras_rsp_frame, tvb, 0, 0, h225ras_call->rsp_num,
 					                           "The response to this request is in frame %u",
@@ -491,6 +487,10 @@ static void ras_call_matching(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 						}
 						h225ras_call = h225ras_call->next_call;
 					} while (h225ras_call != NULL) ;
+					
+					if (!h225ras_call) {
+						return;
+					}
 
 					/* if this is an ACF, ARJ or DCF, DRJ, give guid to tap and make it filterable */
 					if (msg_category == 3 || msg_category == 5) {
