@@ -3,7 +3,7 @@
  *
  * See RFC 1777 (LDAP v2), RFC 2251 (LDAP v3), and RFC 2222 (SASL).
  *
- * $Id: packet-ldap-template.c 26772 2008-11-13 17:54:17Z guy $
+ * $Id: packet-ldap-template.c 27861 2009-03-27 12:16:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1794,14 +1794,9 @@ ldap_reinit(void)
   for (ldap_info = ldap_info_items; ldap_info != NULL; ) {
     ldap_conv_info_t *next;
 
-    if (ldap_info->auth_mech != NULL) {
-      g_free(ldap_info->auth_mech);
-      ldap_info->auth_mech=NULL;
-    }
+    g_free(ldap_info->auth_mech);
     g_hash_table_destroy(ldap_info->matched);
-    ldap_info->matched=NULL;
     g_hash_table_destroy(ldap_info->unmatched);
-    ldap_info->unmatched=NULL;
 
     next = ldap_info->next;
     g_free(ldap_info);
