@@ -2,7 +2,7 @@
  * Routines for QSIG packet dissection
  * 2007  Tomas Kukosa
  *
- * $Id: packet-qsig-template.c 25335 2008-05-21 05:41:39Z etxrab $
+ * $Id: packet-qsig-template.c 27390 2009-02-07 14:33:47Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,9 +28,7 @@
 #endif
 
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include <epan/strutil.h>
-#include <epan/emem.h>
 #include <epan/asn1.h>
 
 #include "packet-ber.h"
@@ -312,11 +310,7 @@ static gint ett_qsig_unknown_extension = -1;
 
 /* Preferences */
 
-/* Subdissectors */
-static dissector_handle_t q931_handle = NULL; 
-static dissector_handle_t data_handle = NULL; 
-
-/* Gloabl variables */
+/* Global variables */
 static const char *extension_oid = NULL;
 
 /* Dissector tables */
@@ -643,13 +637,13 @@ void proto_register_qsig(void) {
 /*--- proto_reg_handoff_qsig ------------------------------------------------*/
 void proto_reg_handoff_qsig(void) {
   int i;
+  dissector_handle_t q931_handle; 
   dissector_handle_t qsig_arg_handle;
   dissector_handle_t qsig_res_handle;
   dissector_handle_t qsig_err_handle;
   dissector_handle_t qsig_ie_handle;
 
   q931_handle = find_dissector("q931");
-  data_handle = find_dissector("data");
 
   qsig_arg_handle = new_create_dissector_handle(dissect_qsig_arg, proto_qsig);
   qsig_res_handle = new_create_dissector_handle(dissect_qsig_res, proto_qsig);
