@@ -17,7 +17,7 @@
  * See RFC 2578 for Structure of Management Information Version 2 (SMIv2)
  * Copyright (C) 2007 Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-snmp-template.c 27719 2009-03-13 22:21:22Z stig $
+ * $Id: packet-snmp-template.c 29119 2009-07-16 17:07:43Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -126,7 +126,7 @@ static void snmp_usm_password_to_key_sha1(const guint8 *password, guint password
 static snmp_usm_auth_model_t model_md5 = {snmp_usm_password_to_key_md5, snmp_usm_auth_md5, 16};
 static snmp_usm_auth_model_t model_sha1 = {snmp_usm_password_to_key_sha1, snmp_usm_auth_sha1, 20};
 
-static value_string auth_types[] = {
+static const value_string auth_types[] = {
 	{0,"MD5"},
 	{1,"SHA1"},
 	{0,NULL}
@@ -134,7 +134,7 @@ static value_string auth_types[] = {
 static snmp_usm_auth_model_t* auth_models[] = {&model_md5,&model_sha1};
 
 
-static value_string priv_types[] = {
+static const value_string priv_types[] = {
 	{0,"DES"},
 	{1,"AES"},
 	{0,NULL}
@@ -694,7 +694,7 @@ show_oid_index:
 	}
 indexing_done:
 
-	if (oid_info_is_ok) {
+	if (oid_info_is_ok && oid_info->value_type) {
 		if (ber_class == BER_CLASS_UNI && tag == BER_UNI_TAG_NULL) {
 			pi_value = proto_tree_add_item(pt_varbind,hf_snmp_unSpecified,tvb,value_offset,value_len,FALSE);
 		}  else {
@@ -1232,7 +1232,7 @@ static gboolean snmp_usm_auth_sha1(snmp_usm_params_t* p _U_, guint8** calc_auth_
 	return ( memcmp(auth,calc_auth,12) != 0 ) ? FALSE : TRUE;
 }
 
-static tvbuff_t* snmp_usm_priv_des(snmp_usm_params_t* p _U_, tvbuff_t* encryptedData _U_, gchar const** error _U_) {
+static tvbuff_t* snmp_usm_priv_des(snmp_usm_params_t* p _U_, tvbuff_t* encryptedData , gchar const** error _U_) {
 #ifdef HAVE_LIBGCRYPT
     gcry_error_t err;
     gcry_cipher_hd_t hd = NULL;
@@ -1290,7 +1290,7 @@ static tvbuff_t* snmp_usm_priv_des(snmp_usm_params_t* p _U_, tvbuff_t* encrypted
 
 	gcry_cipher_close(hd);
 
-	clear_tvb = tvb_new_real_data(cleartext, cryptgrm_len, cryptgrm_len);
+	clear_tvb = tvb_new_child_real_data(encryptedData, cleartext, cryptgrm_len, cryptgrm_len);
 
 	return clear_tvb;
 
@@ -1304,7 +1304,7 @@ on_gcry_error:
 #endif
 }
 
-static tvbuff_t* snmp_usm_priv_aes(snmp_usm_params_t* p _U_, tvbuff_t* encryptedData _U_, gchar const** error _U_) {
+static tvbuff_t* snmp_usm_priv_aes(snmp_usm_params_t* p _U_, tvbuff_t* encryptedData , gchar const** error _U_) {
 #ifdef HAVE_LIBGCRYPT
     gcry_error_t err;
     gcry_cipher_hd_t hd = NULL;
@@ -1353,7 +1353,7 @@ static tvbuff_t* snmp_usm_priv_aes(snmp_usm_params_t* p _U_, tvbuff_t* encrypted
 
 	gcry_cipher_close(hd);
 
-	clear_tvb = tvb_new_real_data(cleartext, cryptgrm_len, cryptgrm_len);
+	clear_tvb = tvb_new_child_real_data(encryptedData, cleartext, cryptgrm_len, cryptgrm_len);
 
 	return clear_tvb;
 
@@ -1992,10 +1992,11 @@ void proto_register_snmp(void) {
 								"Table of engine-user associations used for authentication and decryption",
 								assocs_uat);
 
-
+#ifdef HAVE_LIBSMI
   prefs_register_static_text_preference(snmp_module, "info_mibs",
       "MIB settings can be changed in the Name Resolution preferences",
       "MIB settings can be changed in the Name Resolution preferences");
+#endif
 
 	value_sub_dissectors_table = register_dissector_table("snmp.variable_oid","SNMP Variable OID", FT_STRING, BASE_NONE);
 
