@@ -1,7 +1,7 @@
 /* dftest.c
  * Shows display filter byte-code, for debugging dfilter routines.
  *
- * $Id: dftest.c 27456 2009-02-15 21:47:57Z guy $
+ * $Id: dftest.c 27814 2009-03-22 06:53:17Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -75,7 +75,7 @@ main(int argc, char **argv)
 	/*
 	 * Attempt to get the pathname of the executable file.
 	 */
-	init_progfile_dir_error = init_progfile_dir(argv[0]);
+	init_progfile_dir_error = init_progfile_dir(argv[0], main);
 	if (init_progfile_dir_error != NULL) {
 		fprintf(stderr, "dftest: Can't get pathname of dftest program: %s.\n",
 		    init_progfile_dir_error);
