@@ -1,7 +1,7 @@
 /* addr_resolv.h
  * Definitions for network object lookup
  *
- * $Id: addr_resolv.h 23016 2007-09-28 18:23:59Z bondolo $
+ * $Id: addr_resolv.h 25672 2008-07-08 02:25:30Z wmeier $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -123,19 +123,19 @@ void get_addr_name_buf(address *addr, gchar *buf, guint size);
 /* host_name_lookup_init fires up an ADNS socket if we're using ADNS */
 extern void host_name_lookup_init(void);
 
-/* host_name_lookup_process does ADNS processing in GTK+ timeouts in Wireshark,
+/* host_name_lookup_process does ADNS processing in GLIB timeouts in Wireshark,
    and before processing each packet in TShark, if we're using ADNS */
-extern gint host_name_lookup_process(gpointer data);
+extern gboolean host_name_lookup_process(gpointer data);
 
 /* host_name_lookup_cleanup cleans up an ADNS socket if we're using ADNS */
 extern void host_name_lookup_cleanup(void);
 
 /* get_hostname returns the host name or "%d.%d.%d.%d" if not found */
-extern gchar *get_hostname(guint addr);
+extern const gchar *get_hostname(guint addr);
 
 /* get_hostname6 returns the host name, or numeric addr if not found */
 struct e_in6_addr;
-const gchar* get_hostname6(struct e_in6_addr *ad);
+extern const gchar* get_hostname6(struct e_in6_addr *ad);
 
 /* get_ether_name returns the logical name if found in ethers files else
    "<vendor>_%02x:%02x:%02x" if the vendor code is known else
