@@ -6,7 +6,7 @@
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
  *
- * $Id: packet-app-pkix-cert.c 21753 2007-05-13 20:58:29Z etxrab $
+ * $Id: packet-app-pkix-cert.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -86,7 +86,7 @@ proto_register_cert(void)
          */
         static hf_register_info hf[] = {
                 { &hf_cert,
-                { "Certififcate", "cert", FT_NONE, BASE_HEX, NULL, 0x00, "Certificate", HFILL}},
+                { "Certificate", "cert", FT_NONE, BASE_HEX, NULL, 0x00, "Certificate", HFILL}},
         };
 
         /* Setup protocol subtree array */
