@@ -6,7 +6,7 @@
  * Copyright 2003-2005 Fred Hoekstra, Philips Medical Systems.
  *                (fred.hoekstra@philips.com)
  *
- * $Id: packet-dec-dnart.c 27028 2008-12-17 00:08:38Z wmeier $
+ * $Id: packet-dec-dnart.c 27983 2009-04-07 12:20:41Z wmeier $
  *
  * Use was made of the following documentation:
  * (See URL http://linux-decnet.sourceforge.net/docs).
@@ -1312,11 +1312,6 @@ handle_disc_init_contents(
 }
 
 
-static const true_false_string yesno = {
-    "Yes",
-    "No"
-};
-
 void
 proto_register_dec_rt(void)
 {
@@ -1329,7 +1324,7 @@ proto_register_dec_rt(void)
           "DNA routing flag", HFILL }},
     { &hf_dec_rt_ctrl_msg,
       { "Control packet",            "dec_dna.flags.control",
-        FT_BOOLEAN,    8,        TFS(&yesno),    RT_FLAGS_CTRL_MSG,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    RT_FLAGS_CTRL_MSG,
           "Control packet", HFILL }},
     { &hf_dec_rt_long_msg,
       { "Long data packet format",     "dec_dna.flags.msglen",
@@ -1341,19 +1336,19 @@ proto_register_dec_rt(void)
           "Short message indicator", HFILL }},
     { &hf_dec_rt_rqr,
       { "Return to Sender Request",    "dec_dna.flags.RQR",
-        FT_BOOLEAN,    8,        TFS(&yesno),    RT_FLAGS_RQR,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    RT_FLAGS_RQR,
           "Return to Sender", HFILL }},
     { &hf_dec_rt_rts,
       { "Packet on return trip",    "dec_dna.flags.RTS",
-        FT_BOOLEAN,    8,        TFS(&yesno),    RT_FLAGS_RTS,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    RT_FLAGS_RTS,
           "Packet on return trip", HFILL }},
     { &hf_dec_rt_inter_eth,
       { "Intra-ethernet packet",    "dec_dna.flags.intra_eth",
-        FT_BOOLEAN,    8,        TFS(&yesno),    RT_FLAGS_INTRA_ETHER,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    RT_FLAGS_INTRA_ETHER,
           "Intra-ethernet packet", HFILL }},
     { &hf_dec_rt_discard,
       { "Discarded packet",            "dec_dna.flags.discard",
-        FT_BOOLEAN,    8,        TFS(&yesno),    RT_FLAGS_DISCARD,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    RT_FLAGS_DISCARD,
           "Discarded packet", HFILL }},
     { &hf_dec_rt_dst_addr,
       { "Destination Address",        "dec_dna.dst.address",
@@ -1409,7 +1404,7 @@ proto_register_dec_rt(void)
           "Segment number", HFILL }},
     { &hf_dec_rt_delay,
       { "Delayed ACK allowed",  "dec_dna.nsp.delay",
-        FT_BOOLEAN,    16,        TFS(&yesno),    0x1000,
+        FT_BOOLEAN,    16,        TFS(&tfs_yes_no),    0x1000,
           "Delayed ACK allowed?", HFILL }},
     { &hf_dec_rt_visited_nodes,
       { "Nodes visited ty this package", "dec_dna.vst_node",
@@ -1486,23 +1481,23 @@ proto_register_dec_rt(void)
           "Node type", HFILL }},
     { &hf_dec_rt_iinfo_vrf,
       { "Verification required",            "dec_dna.ctl.iinfo.vrf",
-        FT_BOOLEAN,    8,        TFS(&yesno),    0x4,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    0x4,
           "Verification required?", HFILL }},
     { &hf_dec_rt_iinfo_rej,
       { "Rejected",            "dec_dna.ctl.iinfo.rej",
-        FT_BOOLEAN,    8,        TFS(&yesno),    0x8,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    0x8,
           "Rejected message", HFILL }},
     { &hf_dec_rt_iinfo_verf,
       { "Verification failed",            "dec_dna.ctl.iinfo.verf",
-        FT_BOOLEAN,    8,        TFS(&yesno),    0x10,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    0x10,
           "Verification failed?", HFILL }},
     { &hf_dec_rt_iinfo_mta,
       { "Accepts multicast traffic",            "dec_dna.ctl.iinfo.mta",
-        FT_BOOLEAN,    8,        TFS(&yesno),    0x20,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    0x20,
           "Accepts multicast traffic?", HFILL }},
     { &hf_dec_rt_iinfo_blkreq,
       { "Blocking requested",            "dec_dna.ctl.iinfo.blkreq",
-        FT_BOOLEAN,    8,        TFS(&yesno),    0x40,
+        FT_BOOLEAN,    8,        TFS(&tfs_yes_no),    0x40,
           "Blocking requested?", HFILL }},
     { &hf_dec_rt_iprio,
       { "Routing priority",        "dec_dna.ctl.prio",
