@@ -1,7 +1,7 @@
 /* packet-ipsec.c
  * Routines for IPsec/IPComp packet disassembly
  *
- * $Id: packet-ipsec.c 25274 2008-05-11 17:27:41Z wmeier $
+ * $Id: packet-ipsec.c 28363 2009-05-14 19:28:07Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,6 +43,7 @@ DES-CBC [RFC2405] : keylen 64 bits
 - Add ESP Payload Decryption support for the following Encryption Algorithms :
 BLOWFISH-CBC : keylen 128 bits.
 TWOFISH-CBC : keylen 128/256 bits.
+CAST5-CBC :  keylen 128
 
 - Check ESP Authentication for the following Algorithms defined in RFC 4305:
 
@@ -55,7 +56,7 @@ AES-XCBC-MAC-96 [RFC3566] : Not available because no implementation found.
 
 - Add ESP Authentication checking for the following Authentication Algorithm :
 HMAC-SHA256 : any keylen
-
+HMAC-RIPEMD160-96 [RFC2857] : any keylen
 */
 
 #ifdef HAVE_CONFIG_H
@@ -118,11 +119,15 @@ static dissector_table_t ip_dissector_table;
 #define IPSEC_ENCRYPT_BLOWFISH_CBC 5
 #define IPSEC_ENCRYPT_TWOFISH_CBC 6
 
+/* Encryption algorithm defined in RFC 2144 */
+#define IPSEC_ENCRYPT_CAST5_CBC 7
+
 /* Authentication algorithms defined in RFC 4305 */
 #define IPSEC_AUTH_NULL 0
 #define IPSEC_AUTH_HMAC_SHA1_96 1
 #define IPSEC_AUTH_HMAC_SHA256 2
 #define IPSEC_AUTH_HMAC_MD5_96 3
+#define IPSEC_AUTH_HMAC_RIPEMD160_96 4
 #define IPSEC_AUTH_ANY_12BYTES 5
 /* define IPSEC_AUTH_AES_XCBC_MAC_96 6 */
 #endif
@@ -1157,42 +1162,8 @@ compute_ascii_key(gchar **ascii_key, gchar *key)
 	   * as a sequence of hex digits.
 	   */
 	  i = 2;	/* first character after "0[Xx]" */
-	  if(strlen(key) %2  == 0)
-	    {
-	      /*
-	       * Key has an even number of characters, so we treat each
-	       * pair of hex digits as a single byte value.
-	       */
-	      key_len = (strlen(key) - 2) / 2;
-	      *ascii_key = (gchar *) g_malloc ((key_len + 1)* sizeof(gchar));
-	      j = 0;
-	      while(i < (strlen(key) -1))
-		{
-		  hex_digit = g_ascii_xdigit_value(key[i]);
-		  i++;
-		  if (hex_digit == -1)
-		    {
-		      g_free(*ascii_key);
-		      *ascii_key = NULL;
-		      return -1;	/* not a valid hex digit */
-		    }
-		  key_byte = ((guchar)hex_digit) << 8;
-		  hex_digit = g_ascii_xdigit_value(key[i]);
-		  i++;
-		  if (hex_digit == -1)
-		    {
-		      g_free(*ascii_key);
-		      *ascii_key = NULL;
-		      return -1;	/* not a valid hex digit */
-		    }
-		  key_byte |= (guchar)hex_digit;
-		  (*ascii_key)[j] = key_byte;
-		  j++;
-		}
-	      (*ascii_key)[j] = '\0';
-	    }
-
-	  else
+	  j = 0;
+	  if(strlen(key) %2  == 1)
 	    {
 	      /*
 	       * Key has an odd number of characters; we act as if the
@@ -1201,7 +1172,6 @@ compute_ascii_key(gchar **ascii_key, gchar *key)
 	       */
 	      key_len = (strlen(key) - 2) / 2 + 1;
 	      *ascii_key = (gchar *) g_malloc ((key_len + 1)* sizeof(gchar));
-	      j = 0;
 	      hex_digit = g_ascii_xdigit_value(key[i]);
 	      i++;
 	      if (hex_digit == -1)
@@ -1212,31 +1182,41 @@ compute_ascii_key(gchar **ascii_key, gchar *key)
 		}
 	      (*ascii_key)[j] = (guchar)hex_digit;
 	      j++;
-	      while(i < (strlen(key) -1))
-		{
-		  hex_digit = g_ascii_xdigit_value(key[i]);
-		  i++;
-		  if (hex_digit == -1)
-		    {
-		      g_free(*ascii_key);
-		      *ascii_key = NULL;
-		      return -1;	/* not a valid hex digit */
-		    }
-		  key_byte = ((guchar)hex_digit) << 8;
-		  hex_digit = g_ascii_xdigit_value(key[i]);
-		  i++;
-		  if (hex_digit == -1)
-		    {
-		      g_free(*ascii_key);
-		      *ascii_key = NULL;
-		      return -1;	/* not a valid hex digit */
-		    }
-		  key_byte |= (guchar)hex_digit;
-		  (*ascii_key)[j] = key_byte;
-		  j++;
-		}
-	      (*ascii_key)[j] = '\0';
-	    }
+	     } 
+	   else 
+	     {
+	       /*
+	        * Key has an even number of characters, so we treat each
+	        * pair of hex digits as a single byte value.
+	        */
+	       key_len = (strlen(key) - 2) / 2;
+	      *ascii_key = (gchar *) g_malloc ((key_len + 1)* sizeof(gchar));
+	     }
+	     
+	   while(i < (strlen(key) -1))
+	     {
+	       hex_digit = g_ascii_xdigit_value(key[i]);
+	       i++;
+	       if (hex_digit == -1)
+	         {
+		   g_free(*ascii_key);
+		   *ascii_key = NULL;
+		   return -1;	/* not a valid hex digit */
+		 }
+	       key_byte = ((guchar)hex_digit) << 4;
+	       hex_digit = g_ascii_xdigit_value(key[i]);
+	       i++;
+	       if (hex_digit == -1)
+	         {
+		   g_free(*ascii_key);
+		   *ascii_key = NULL;
+		   return -1;	/* not a valid hex digit */
+		 }
+	       key_byte |= (guchar)hex_digit;
+	       (*ascii_key)[j] = key_byte;
+	       j++;
+	     }
+	   (*ascii_key)[j] = '\0';
 	}
 
       else if((strlen(key) == 2) && (key[0] == '0') && ((key[1] == 'x') || (key[1] == 'X')))
@@ -1792,6 +1772,12 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		    break;
 		  }
 
+		case IPSEC_AUTH_HMAC_RIPEMD160_96:
+		  {
+		    esp_auth_len = 12;
+		    break;
+		  }
+
 		case IPSEC_AUTH_ANY_12BYTES:
 		default:
 		  {
@@ -1870,6 +1856,20 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		      }
 
+		    case IPSEC_AUTH_HMAC_RIPEMD160_96:
+		      /*
+			RFC 2857 : HMAC-RIPEMD-160-96 produces a 160-bit 
+			authenticator value.  This 160-bit value can be 
+			truncated as described in RFC2104.  For use with 
+			either ESP or AH, a truncated value using the first 
+			96 bits MUST be supported. 
+		      */
+		      {
+			auth_algo_libgcrypt = GCRY_MD_RMD160;
+			authentication_check_using_hmac_libgcrypt = TRUE;
+			break;
+		      }
+
 		    case IPSEC_AUTH_ANY_12BYTES:
 		    default:
 		      {
@@ -2063,6 +2063,50 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		      }
 
 
+		    case IPSEC_ENCRYPT_CAST5_CBC :
+		      {
+			/* RFC 2144 says :
+			   The CAST-128 encryption algorithm has been designed to allow a key
+			   size that can vary from 40 bits to 128 bits, in 8-bit increments
+			   (that is, the allowable key sizes are 40, 48, 56, 64, ..., 112, 120,
+			   and 128 bits. 
+			   We support only 128 bits. */
+
+			/* Fix parameters for CAST5-CBC */
+			esp_iv_len = 8;
+			crypt_mode_libgcrypt = GCRY_CIPHER_MODE_CBC;
+
+			decrypted_len = len - sizeof(struct newesp);
+
+			if (decrypted_len <= 0)
+			  decrypt_ok = FALSE;
+			else
+			  {
+			    if(decrypted_len % esp_iv_len  == 0)
+			      decrypted_len_alloc = decrypted_len;
+			    else
+			      decrypted_len_alloc = (decrypted_len / esp_iv_len) * esp_iv_len + esp_iv_len;
+
+			    switch(esp_crypt_key_len * 8)
+			      {
+			      case 128:
+				{
+				  crypt_algo_libgcrypt = GCRY_CIPHER_CAST5;
+				  decrypt_using_libgcrypt = TRUE;
+				  break;
+				}
+			      default:
+				{
+				  fprintf (stderr,"<ESP Preferences> Error in Encryption Algorithm CAST5-CBC : Bad Keylen (%i Bits)\n",
+				           esp_crypt_key_len * 8);
+				  decrypt_ok = FALSE;
+				}
+			      }
+			  }
+			break;
+		      }
+
+
 		    case IPSEC_ENCRYPT_DES_CBC :
 		      {
 			/* RFC 2405 says :
@@ -2334,8 +2378,8 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		  if(decrypt_ok)
 		    {
-		      tvb_decrypted = tvb_new_real_data(decrypted_data, decrypted_len, decrypted_len);
-		      tvb_set_child_real_data_tvbuff(tvb, tvb_decrypted);
+		      tvb_decrypted = tvb_new_child_real_data(tvb, g_memdup(decrypted_data+sizeof(guint8)*esp_iv_len,(decrypted_len - esp_iv_len)*sizeof(guint8)), decrypted_len - esp_iv_len, decrypted_len - esp_iv_len);
+		      g_free(decrypted_data);
 
 		      add_new_data_source(pinfo,
 					  tvb_decrypted,
@@ -2344,34 +2388,34 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		      /* Handler to free the Decrypted Data Buffer. */
 		      tvb_set_free_cb(tvb_decrypted,g_free);
 		      
-		      if(tvb_bytes_exist(tvb_decrypted, 0, esp_iv_len))
+		      if(tvb_bytes_exist(tvb, 8, esp_iv_len))
 			{
 			  if(esp_iv_len > 0)
 			    proto_tree_add_item(esp_tree, hf_esp_iv,
-						tvb_decrypted,
-						0, esp_iv_len,
+						tvb,
+						8, esp_iv_len,
 						FALSE);
 			}
 
 		      else
-			proto_tree_add_text(esp_tree, tvb_decrypted,
-					    0, -1,
+			proto_tree_add_text(esp_tree, tvb,
+					    8, -1,
 					    "IV (truncated)");
 
 		      /* Make sure the packet is not truncated before the fields
 		       * we need to read to determine the encapsulated protocol */
-		      if(tvb_bytes_exist(tvb_decrypted, decrypted_len - esp_auth_len - 2, 2))
+		      if(tvb_bytes_exist(tvb_decrypted, decrypted_len - esp_iv_len - esp_auth_len - 2, 2))
 			{
-			  esp_pad_len = tvb_get_guint8(tvb_decrypted, decrypted_len - esp_auth_len - 2);
+			  esp_pad_len = tvb_get_guint8(tvb_decrypted, decrypted_len - esp_iv_len - esp_auth_len - 2);
 
-			  if(decrypted_len - esp_auth_len - esp_pad_len - esp_iv_len - 2 >= esp_iv_len)
+			  if(decrypted_len - esp_iv_len - esp_auth_len - esp_pad_len - 2 >= 0)
 			    {
 			      /* Get the encapsulated protocol */
-			      encapsulated_protocol = tvb_get_guint8(tvb_decrypted, decrypted_len - esp_auth_len - 1);
+			      encapsulated_protocol = tvb_get_guint8(tvb_decrypted, decrypted_len - esp_iv_len - esp_auth_len - 1);
 
 			      if(dissector_try_port(ip_dissector_table,
 						    encapsulated_protocol,
-						    tvb_new_subset(tvb_decrypted, esp_iv_len,
+						    tvb_new_subset(tvb_decrypted, 0,
 								   decrypted_len - esp_auth_len - esp_pad_len - esp_iv_len - 2,
 								   decrypted_len - esp_auth_len - esp_pad_len - esp_iv_len - 2),
 						    pinfo,
@@ -2388,30 +2432,30 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			  if(esp_tree)
 			    {
 			      if(esp_pad_len !=0)
-				proto_tree_add_text(esp_tree, tvb_decrypted, decrypted_len - esp_auth_len - 2 - esp_pad_len, esp_pad_len,"Pad");
+				proto_tree_add_text(esp_tree, tvb_decrypted, decrypted_len - esp_iv_len - esp_auth_len - 2 - esp_pad_len, esp_pad_len,"Pad");
 
 			      proto_tree_add_uint(esp_tree, hf_esp_pad_len, tvb_decrypted,
-						  decrypted_len - esp_auth_len - 2, 1,
+						  decrypted_len - esp_iv_len - esp_auth_len - 2, 1,
 						  esp_pad_len);
 
 			      proto_tree_add_uint_format(esp_tree, hf_esp_protocol, tvb_decrypted,
-					 decrypted_len - esp_auth_len - 1, 1,
+					 decrypted_len - esp_iv_len - esp_auth_len - 1, 1,
 					 encapsulated_protocol,
 					"Next header: %s (0x%02x)",
 					 ipprotostr(encapsulated_protocol), encapsulated_protocol);
 
-			      dissect_esp_authentication(esp_tree, tvb_decrypted, decrypted_len, esp_auth_len, authenticator_data_computed, authentication_ok, authentication_checking_ok );
+			      dissect_esp_authentication(esp_tree, tvb_decrypted, decrypted_len - esp_iv_len, esp_auth_len, authenticator_data_computed, authentication_ok, authentication_checking_ok );
 
 			    }
 			}
 		      else
 			{
 			  call_dissector(data_handle,
-					 tvb_new_subset(tvb_decrypted, 0, decrypted_len - esp_auth_len, decrypted_len - esp_auth_len),
+					 tvb_new_subset(tvb_decrypted, 0, decrypted_len - esp_iv_len - esp_auth_len, decrypted_len - esp_iv_len - esp_auth_len),
 					 pinfo, esp_tree);
 
 			  if(esp_tree)
-			    dissect_esp_authentication(esp_tree, tvb_decrypted, decrypted_len, esp_auth_len, authenticator_data_computed, authentication_ok, authentication_checking_ok );
+			    dissect_esp_authentication(esp_tree, tvb_decrypted, decrypted_len - esp_iv_len, esp_auth_len, authenticator_data_computed, authentication_ok, authentication_checking_ok );
 
 			}
 		    }
@@ -2637,6 +2681,7 @@ proto_register_ipsec(void)
     {"aescbc", "AES-CBC [RFC3602]", IPSEC_ENCRYPT_AES_CBC},
     {"aesctr", "AES-CTR [RFC3686]", IPSEC_ENCRYPT_AES_CTR},
     {"descbc", "DES-CBC [RFC2405]", IPSEC_ENCRYPT_DES_CBC},
+    {"cast5cbc", "CAST5-CBC [RFC2144]", IPSEC_ENCRYPT_CAST5_CBC},
     {"blowfishcbc","BLOWFISH-CBC [RFC2451]", IPSEC_ENCRYPT_BLOWFISH_CBC},
     {"twofishcbc","TWOFISH-CBC", IPSEC_ENCRYPT_TWOFISH_CBC},
     {NULL,NULL,0}
@@ -2648,6 +2693,7 @@ proto_register_ipsec(void)
     {"hmacsha196", "HMAC-SHA1-96 [RFC2404]", IPSEC_AUTH_HMAC_SHA1_96},
     {"hmacsha256", "HMAC-SHA256", IPSEC_AUTH_HMAC_SHA256},
     {"hmacmd596", "HMAC-MD5-96 [RFC2403]", IPSEC_AUTH_HMAC_MD5_96},
+    {"hmacripemd160", "HMAC-RIPEMD", IPSEC_AUTH_HMAC_RIPEMD160_96},
     /*    {"aesxcbcmac96", "AES-XCBC-MAC-96 [RFC3566]", IPSEC_AUTH_AES_XCBC_MAC_96}, */
     {"any12bytes", "ANY 12-bytes of Authentication [No Checking]", IPSEC_AUTH_ANY_12BYTES},
     {NULL,NULL,0}
@@ -2735,7 +2781,7 @@ proto_register_ipsec(void)
 
       prefs_register_string_preference(esp_module, name_str->str, title_str->str,
 			"SA identifier.  Must have the form "
-			"\"Protocol|Source Address|Destination Adress|SPI\". "
+			"\"Protocol|Source Address|Destination Address|SPI\". "
 			"Example: \"IPv4|192.168.0.45|10.1.2.7|*\" "
 			"See the ESP Preferences page on the Wireshark wiki "
 			"(http://wiki.wireshark.org/ESP_Preferences) for "
