@@ -2,7 +2,7 @@
  * Routines for IEEE 802.2 LLC layer
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-llc.c 25291 2008-05-14 05:44:42Z jake $
+ * $Id: packet-llc.c 28298 2009-05-08 06:53:43Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -84,15 +84,18 @@ static gint ett_llc = -1;
 static gint ett_llc_ctrl = -1;
 static gint ett_llc_basicxid = -1;
 
-static dissector_table_t subdissector_table;
+static dissector_table_t dsap_subdissector_table;
 static dissector_table_t xid_subdissector_table;
 
+static dissector_table_t ethertype_subdissector_table;
+
 static dissector_handle_t bpdu_handle;
 static dissector_handle_t eth_withoutfcs_handle;
 static dissector_handle_t eth_withfcs_handle;
 static dissector_handle_t fddi_handle;
 static dissector_handle_t tr_handle;
 static dissector_handle_t turbo_handle;
+static dissector_handle_t mesh_handle;
 static dissector_handle_t data_handle;
 
 /*
@@ -184,17 +187,18 @@ const value_string oui_vals[] = {
 /*
 http://www.cisco.com/univercd/cc/td/doc/product/software/ios113ed/113ed_cr/ibm_r/brprt1/brsrb.htm
 */
-	{ OUI_CISCO,			"Cisco" },
-	{ OUI_NORTEL,			"Nortel Networks SONMP" },
-	{ OUI_CISCO_90,			"Cisco IOS 9.0 Compatible" },
-	{ OUI_ERICSSON,			"Ericsson Group" },
+	{ OUI_CISCO,		"Cisco" },
+	{ OUI_NORTEL,		"Nortel Networks SONMP" },
+	{ OUI_CISCO_90,		"Cisco IOS 9.0 Compatible" },
+	{ OUI_FORCE10,		"Force10 Networks" },
+	{ OUI_ERICSSON,		"Ericsson Group" },
+	{ OUI_CATENA,		"Catena Networks" },
 	{ OUI_SONY_ERICSSON,	"Sony Ericsson Mobile Communications AB" },
 	{ OUI_SONY_ERICSSON_2,	"Sony Ericsson Mobile Communications AB" },
-	{ OUI_PROFINET,			"PROFIBUS Nutzerorganisation e.V." },
+	{ OUI_PROFINET,		"PROFIBUS Nutzerorganisation e.V." },
 	{ OUI_SONY_ERICSSON_3,	"Sony Ericsson Mobile Communications AB" },
-	{ OUI_CATENA,			"Catena Networks" },
-	{ OUI_CIMETRICS,		"Cimetrics" },
-	{ OUI_IEEE_802_3,		"IEEE 802.3" },
+	{ OUI_CIMETRICS,	"Cimetrics" },
+	{ OUI_IEEE_802_3,	"IEEE 802.3" },
 	{ OUI_MEDIA_ENDPOINT,	"Media (TIA TR-41 Committee)" },
 	{ OUI_SONY_ERICSSON_4,	"Sony Ericsson Mobile Communications AB" },
 	{ OUI_ERICSSON_MOBILE,	"Ericsson Mobile Platforms" },
@@ -202,18 +206,20 @@ http://www.cisco.com/univercd/cc/td/doc/product/software/ios113ed/113ed_cr/ibm_r
 	{ OUI_SONY_ERICSSON_6,	"Sony Ericsson Mobile Communications AB" },
 	{ OUI_SONY_ERICSSON_7,	"Sony Ericsson Mobile Communications AB" },
 	{ OUI_SONY_ERICSSON_8,	"Sony Ericsson Mobile Communications AB" },
-	{ OUI_CISCOWL,			"Cisco Wireless (Aironet) L2" },
-	{ OUI_ERICSSON_2,			"Ericsson Group" },
-	{ OUI_BRIDGED,			"Frame Relay or ATM bridged frames" },
-	{ OUI_ATM_FORUM,		"ATM Forum" },
-	{ OUI_EXTREME,			"Extreme Networks" },
+	{ OUI_TURBOCELL,	"Karlnet (Turbocell)" },
+	{ OUI_CISCOWL,		"Cisco Wireless (Aironet) L2" },
+	{ OUI_MARVELL,		"Marvell Semiconductor" },
+	{ OUI_ERICSSON_2,	"Ericsson Group" },
+	{ OUI_BRIDGED,		"Frame Relay or ATM bridged frames" },
+	{ OUI_IEEE_802_1,	"IEEE 802.1 Committee" },
+	{ OUI_ATM_FORUM,	"ATM Forum" },
+	{ OUI_EXTREME,		"Extreme Networks" },
 	/* RFC 2427, RFC 2684 */
-	{ OUI_CABLE_BPDU,		"DOCSIS Spanning Tree" }, /* DOCSIS spanning tree BPDU */
-	{ OUI_SIEMENS,			"Siemens AG" },
-	{ OUI_APPLE_ATALK,		"Apple (AppleTalk)" },
-	{ OUI_HP,				"Hewlett-Packard" },
-	{ OUI_TURBOCELL,		"Karlnet (Turbocell)" },
-	{ 0,               NULL }
+	{ OUI_CABLE_BPDU,	"DOCSIS Spanning Tree" }, /* DOCSIS spanning tree BPDU */
+	{ OUI_SIEMENS,		"Siemens AG" },
+	{ OUI_APPLE_ATALK,	"Apple (AppleTalk)" },
+	{ OUI_HP,		"Hewlett-Packard" },
+	{ 0,			NULL }
 };
 
 const value_string format_vals[] = {
@@ -238,15 +244,8 @@ const value_string type_vals[] = {
 };
 
 /*
- * Hash table for translating OUIs to a dissector table/field info pair;
- * the dissector table maps PID values to dissectors, and the field
- * corresponds to the PID for that OUI.
+ * Hash table for translating OUIs to an oui_info_t.
  */
-typedef struct {
-	dissector_table_t table;
-	hf_register_info *field_info;
-} oui_info_t;
-
 static GHashTable *oui_info_table = NULL;
 
 /*
@@ -368,6 +367,16 @@ capture_snap(const guchar *pd, int offset, int len, packet_counts *ld)
 		capture_ethertype(etype, pd, offset+5, len, ld);
 		break;
 
+	case OUI_MARVELL:
+		/*
+		 * OLPC packet.  The PID is an Ethertype, but
+		 * there's a mesh header between the PID and
+		 * the payload.  (We assume the header is
+		 * 5 bytes, for now).
+		 */
+		capture_ethertype(etype, pd, offset+5+5, len, ld);
+		break;
+
 	default:
 		ld->other++;
 		break;
@@ -531,7 +540,7 @@ dissect_llc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				 * Try the regular LLC subdissector table
 				 * with the DSAP.
 				 */
-				if (!dissector_try_port(subdissector_table,
+				if (!dissector_try_port(dsap_subdissector_table,
 				    dsap, next_tvb, pinfo, tree)) {
 					call_dissector(data_handle, next_tvb,
 					    pinfo, tree);
@@ -579,6 +588,7 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 	oui_info_t	*oui_info;
 	dissector_table_t subdissector_table;
 	int		hf;
+	int		mesh_header_len;
 
 	/*
 	 * XXX - what about non-UI frames?
@@ -608,11 +618,18 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 		   OUI_ENCAP_ETHER and an Ethernet
 		   packet type for AARP packets. */
 		if (XDLC_IS_INFORMATION(control)) {
-			ethertype(etype, tvb, offset+5,
-			    pinfo, tree, snap_tree, hf_type, -1, 0);
+			if (tree) {
+				proto_tree_add_uint(snap_tree, hf_type,
+				    tvb, offset+3, 2, etype);
+			}
+			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			if (!dissector_try_port(ethertype_subdissector_table,
+			    etype, next_tvb, pinfo, tree))
+				call_dissector(data_handle, next_tvb, pinfo,
+				    tree);
 		} else {
 			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
-			call_dissector(data_handle,next_tvb, pinfo, tree);
+			call_dissector(data_handle, next_tvb, pinfo, tree);
 		}
 		break;
 
@@ -674,7 +691,7 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 
 		default:
 			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
-			call_dissector(data_handle,next_tvb, pinfo, tree);
+			call_dissector(data_handle, next_tvb, pinfo, tree);
 			break;
 		}
 		break;
@@ -693,14 +710,38 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 		call_dissector(turbo_handle, next_tvb, pinfo, tree);
 		break;
 
+	case OUI_MARVELL:
+		/*
+		 * OLPC packet.  The PID is an Ethertype, but
+		 * there's a mesh header between the PID and
+		 * the payload.
+		 */
+		if (XDLC_IS_INFORMATION(control)) {
+			if (tree) {
+				proto_tree_add_uint(snap_tree, hf_type,
+				    tvb, offset+3, 2, etype);
+			}
+			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			mesh_header_len = call_dissector(mesh_handle,
+			    next_tvb, pinfo, tree);
+			next_tvb = tvb_new_subset(tvb, offset+5+mesh_header_len,
+			    -1, -1);
+			if (!dissector_try_port(ethertype_subdissector_table,
+			    etype, next_tvb, pinfo, tree))
+				call_dissector(data_handle, next_tvb, pinfo,
+				    tree);
+		} else {
+			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			call_dissector(data_handle, next_tvb, pinfo, tree);
+		}
+		break;
+
 	default:
 		/*
 		 * Do we have information for this OUI?
 		 */
-		if (oui_info_table != NULL &&
-		    (oui_info =
-		     g_hash_table_lookup(oui_info_table,
-		      GUINT_TO_POINTER(oui))) != NULL) {
+		oui_info = get_snap_oui_info(oui);
+		if (oui_info != NULL) {
 			/*
 			 * Yes - use it.
 			 */
@@ -732,6 +773,20 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 	}
 }
 
+/*
+ * Return the oui_info_t for the PID for a particular OUI value, or NULL
+ * if there isn't one.
+ */
+oui_info_t *
+get_snap_oui_info(guint32 oui)
+{
+	if (oui_info_table != NULL) {
+		return g_hash_table_lookup(oui_info_table,
+		    GUINT_TO_POINTER(oui));
+	} else
+		return NULL;
+}
+
 void
 proto_register_llc(void)
 {
@@ -744,93 +799,93 @@ proto_register_llc(void)
 			VALS(sap_vals), 0x0, "DSAP - 7 Most Significant Bits only", HFILL }},
 
 		{ &hf_llc_dsap_ig,
-		{ "IG Bit",	"llc.dsap.ig", FT_BOOLEAN, BASE_HEX,
-			&ig_bit, 0x0, "Individual/Group - Least Significant Bit only", HFILL }},
+		{ "IG Bit",	"llc.dsap.ig", FT_BOOLEAN, 8,
+			TFS(&ig_bit), 0x0, "Individual/Group - Least Significant Bit only", HFILL }},
 
 		{ &hf_llc_ssap,
 		{ "SSAP", "llc.ssap", FT_UINT8, BASE_HEX,
 			VALS(sap_vals), 0x0, "SSAP - 7 Most Significant Bits only", HFILL }},
 
 		{ &hf_llc_ssap_cr,
-		{ "CR Bit", "llc.ssap.cr", FT_BOOLEAN, BASE_HEX,
-			&cr_bit, 0x0, "Command/Response - Least Significant Bit only", HFILL }},
+		{ "CR Bit", "llc.ssap.cr", FT_BOOLEAN, 8,
+			TFS(&cr_bit), 0x0, "Command/Response - Least Significant Bit only", HFILL }},
 
 		{ &hf_llc_ctrl,
 		{ "Control", "llc.control", FT_UINT16, BASE_HEX,
-			NULL, 0x0, "", HFILL }},
+			NULL, 0x0, NULL, HFILL }},
 
 		{ &hf_llc_n_r,
 		{ "N(R)", "llc.control.n_r", FT_UINT16, BASE_DEC,
-			NULL, XDLC_N_R_EXT_MASK, "", HFILL }},
+			NULL, XDLC_N_R_EXT_MASK, NULL, HFILL }},
 
 		{ &hf_llc_n_s,
 		{ "N(S)", "llc.control.n_s", FT_UINT16, BASE_DEC,
-			NULL, XDLC_N_S_EXT_MASK, "", HFILL }},
+			NULL, XDLC_N_S_EXT_MASK, NULL, HFILL }},
 
 		{ &hf_llc_p,
 		{ "Poll", "llc.control.p", FT_BOOLEAN, 8,
-			TFS(&flags_set_truth), XDLC_P_F, "", HFILL }},
+			TFS(&flags_set_truth), XDLC_P_F, NULL, HFILL }},
 
 		{ &hf_llc_p_ext,
 		{ "Poll", "llc.control.p", FT_BOOLEAN, 16,
-			TFS(&flags_set_truth), XDLC_P_F_EXT, "", HFILL }},
+			TFS(&flags_set_truth), XDLC_P_F_EXT, NULL, HFILL }},
 
 		{ &hf_llc_f,
 		{ "Final", "llc.control.f", FT_BOOLEAN, 8,
-			TFS(&flags_set_truth), XDLC_P_F, "", HFILL }},
+			TFS(&flags_set_truth), XDLC_P_F, NULL, HFILL }},
 
 		{ &hf_llc_f_ext,
 		{ "Final", "llc.control.f", FT_BOOLEAN, 16,
-			TFS(&flags_set_truth), XDLC_P_F_EXT, "", HFILL }},
+			TFS(&flags_set_truth), XDLC_P_F_EXT, NULL, HFILL }},
 
 		{ &hf_llc_s_ftype,
 		{ "Supervisory frame type", "llc.control.s_ftype", FT_UINT16, BASE_HEX,
-			VALS(stype_vals), XDLC_S_FTYPE_MASK, "", HFILL }},
+			VALS(stype_vals), XDLC_S_FTYPE_MASK, NULL, HFILL }},
 
 		{ &hf_llc_u_modifier_cmd,
 		{ "Command", "llc.control.u_modifier_cmd", FT_UINT8, BASE_HEX,
-			VALS(modifier_vals_cmd), XDLC_U_MODIFIER_MASK, "", HFILL }},
+			VALS(modifier_vals_cmd), XDLC_U_MODIFIER_MASK, NULL, HFILL }},
 
 		{ &hf_llc_u_modifier_resp,
 		{ "Response", "llc.control.u_modifier_resp", FT_UINT8, BASE_HEX,
-			VALS(modifier_vals_resp), XDLC_U_MODIFIER_MASK, "", HFILL }},
+			VALS(modifier_vals_resp), XDLC_U_MODIFIER_MASK, NULL, HFILL }},
 
 		{ &hf_llc_ftype_i,
 		{ "Frame type", "llc.control.ftype", FT_UINT16, BASE_HEX,
-			VALS(ftype_vals), XDLC_I_MASK, "", HFILL }},
+			VALS(ftype_vals), XDLC_I_MASK, NULL, HFILL }},
 
 		{ &hf_llc_ftype_s_u,
 		{ "Frame type", "llc.control.ftype", FT_UINT8, BASE_HEX,
-			VALS(ftype_vals), XDLC_S_U_MASK, "", HFILL }},
+			VALS(ftype_vals), XDLC_S_U_MASK, NULL, HFILL }},
 
 		{ &hf_llc_ftype_s_u_ext,
 		{ "Frame type", "llc.control.ftype", FT_UINT16, BASE_HEX,
-			VALS(ftype_vals), XDLC_S_U_MASK, "", HFILL }},
+			VALS(ftype_vals), XDLC_S_U_MASK, NULL, HFILL }},
 
 		/* registered here but handled in ethertype.c */
 		{ &hf_llc_type,
 		{ "Type", "llc.type", FT_UINT16, BASE_HEX,
-			VALS(etype_vals), 0x0, "", HFILL }},
+			VALS(etype_vals), 0x0, NULL, HFILL }},
 
 		{ &hf_llc_oui,
 		{ "Organization Code",	"llc.oui", FT_UINT24, BASE_HEX,
-			VALS(oui_vals), 0x0, "", HFILL }},
+			VALS(oui_vals), 0x0, NULL, HFILL }},
 
 		{ &hf_llc_pid,
 		{ "Protocol ID", "llc.pid", FT_UINT16, BASE_HEX,
-			NULL, 0x0, "", HFILL }},
+			NULL, 0x0, NULL, HFILL }}
 	};
 	static gint *ett[] = {
 		&ett_llc,
-		&ett_llc_ctrl,
+		&ett_llc_ctrl
 	};
 
 	proto_llc = proto_register_protocol("Logical-Link Control", "LLC", "llc");
 	proto_register_field_array(proto_llc, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
-/* subdissector code */
-	subdissector_table = register_dissector_table("llc.dsap",
+	/* subdissector code */
+	dsap_subdissector_table = register_dissector_table("llc.dsap",
 	  "LLC SAP", FT_UINT8, BASE_HEX);
 	xid_subdissector_table = register_dissector_table("llc.xid_dsap",
 	  "LLC XID SAP", FT_UINT8, BASE_HEX);
@@ -844,18 +899,18 @@ proto_register_basicxid(void)
 	static hf_register_info hf[] = {
 		{ &hf_llc_xid_format,
 		{ "XID Format", "basicxid.llc.xid.format", FT_UINT8, BASE_HEX,
-			VALS(format_vals), 0x0, "", HFILL }},
+			VALS(format_vals), 0x0, NULL, HFILL }},
 
 		{ &hf_llc_xid_types,
 		{ "LLC Types/Classes", "basicxid.llc.xid.types", FT_UINT8, BASE_HEX,
-			VALS(type_vals), 0x0, "", HFILL }},
+			VALS(type_vals), 0x0, NULL, HFILL }},
 
 		{ &hf_llc_xid_wsize,
 		{ "Receive Window Size", "basicxid.llc.xid.wsize", FT_UINT8, BASE_DEC,
-			NULL, 0x0, "", HFILL }},
+			NULL, 0x0, NULL, HFILL }}
 	};
 	static gint *ett[] = {
-		&ett_llc_basicxid,
+		&ett_llc_basicxid
 	};
 
 	proto_basicxid = proto_register_protocol("Logical-Link Control Basic Format XID", "Basic Format XID", "basicxid");
@@ -888,8 +943,14 @@ proto_reg_handoff_llc(void)
 	fddi_handle = find_dissector("fddi");
 	tr_handle = find_dissector("tr");
 	turbo_handle = find_dissector("turbocell");
+	mesh_handle = find_dissector("mesh");
 	data_handle = find_dissector("data");
 
+	/*
+	 * Get the Ethertype dissector table.
+	 */
+	ethertype_subdissector_table = find_dissector_table("ethertype");
+
 	llc_handle = find_dissector("llc");
 	dissector_add("wtap_encap", WTAP_ENCAP_ATM_RFC1483, llc_handle);
 	/* RFC 2043 */
