@@ -1,7 +1,7 @@
 /* packet-ositp.c
  * Routines for ISO/OSI transport protocol packet disassembly
  *
- * $Id: packet-ositp.c 27324 2009-01-28 21:52:57Z wmeier $
+ * $Id: packet-ositp.c 27822 2009-03-22 20:55:31Z wmeier $
  * Laurent Deniel <laurent.deniel@free.fr>
  * Ralf Schneider <Ralf.Schneider@t-online.de>
  *
@@ -311,7 +311,7 @@ static gchar *print_tsap(const guchar *tsap, int length)
 
   gchar *cur;
   gboolean allprintable;
-  size_t idx = 0, returned_length;
+  gint idx = 0, returned_length;
 
   cur=ep_alloc(MAX_TSAP_LEN * 2 + 3);
   cur[0] = '\0';
