@@ -3,7 +3,7 @@
  *
  * Uwe Girlich <uwe@planetquake.com>
  *
- * $Id: packet-quake3.c 26253 2008-09-23 01:10:45Z wmeier $
+ * $Id: packet-quake3.c 28317 2009-05-08 20:35:57Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -618,7 +618,7 @@ proto_register_quake3(void)
 			"Sequence number of the current packet", HFILL }},
 		{ &hf_quake3_game_rel1,
 			{ "Reliable", "quake3.game.rel1",
-			FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+			FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 			"Packet is reliable and may be retransmitted", HFILL }},
 		{ &hf_quake3_game_seq2,
 			{ "Sequence Number", "quake3.game.seq2",
@@ -626,7 +626,7 @@ proto_register_quake3(void)
 			"Sequence number of the last received packet", HFILL }},
 		{ &hf_quake3_game_rel2,
 			{ "Reliable", "quake3.game.rel2",
-			FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+			FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 			"Packet was reliable and may be retransmitted", HFILL }},
 		{ &hf_quake3_game_qport,
 			{ "QPort", "quake3.game.qport",
