@@ -6,7 +6,7 @@
  * Copyright 2000, Philips Electronics N.V.
  * Written by Andreas Sikkema <h323@ramdyne.nl>
  *
- * $Id: packet-rtp.c 27628 2009-03-06 22:55:02Z wmeier $
+ * $Id: packet-rtp.c 28466 2009-05-25 06:46:33Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -304,39 +304,110 @@ const value_string rtp_payload_type_vals[] =
 	{ PT_MPV,	"MPEG-I/II Video"},
 	{ PT_MP2T,	"MPEG-II transport streams"},
 	{ PT_H263,	"ITU-T H.263" },
+ 
+ 	/* Alex Lindberg - Added to support addtional RTP payload types
+ 	See epan/rtp_pt.h */
+	{ PT_UNDF_96,	"DynamicRTP-Type-96" },
+	{ PT_UNDF_97,	"DynamicRTP-Type-97" },
+	{ PT_UNDF_98,	"DynamicRTP-Type-98" },
+	{ PT_UNDF_99,	"DynamicRTP-Type-99" },
+	{ PT_UNDF_100,	"DynamicRTP-Type-100" },
+	{ PT_UNDF_101,	"DynamicRTP-Type-101" },
+	{ PT_UNDF_102,	"DynamicRTP-Type-102" },
+	{ PT_UNDF_103,	"DynamicRTP-Type-103" },
+	{ PT_UNDF_104,	"DynamicRTP-Type-104" },
+	{ PT_UNDF_105,	"DynamicRTP-Type-105" },
+	{ PT_UNDF_106,	"DynamicRTP-Type-106" },
+	{ PT_UNDF_107,	"DynamicRTP-Type-107" },
+	{ PT_UNDF_108,	"DynamicRTP-Type-108" },
+	{ PT_UNDF_109,	"DynamicRTP-Type-109" },
+	{ PT_UNDF_110,	"DynamicRTP-Type-110" },
+	{ PT_UNDF_111,	"DynamicRTP-Type-111" },
+	{ PT_UNDF_112,	"DynamicRTP-Type-112" },
+	{ PT_UNDF_113,	"DynamicRTP-Type-113" },
+	{ PT_UNDF_114,	"DynamicRTP-Type-114" },
+	{ PT_UNDF_115,	"DynamicRTP-Type-115" },
+	{ PT_UNDF_116,	"DynamicRTP-Type-116" },
+	{ PT_UNDF_117,	"DynamicRTP-Type-117" },
+	{ PT_UNDF_118,	"DynamicRTP-Type-118" },
+	{ PT_UNDF_119,	"DynamicRTP-Type-119" },
+	{ PT_UNDF_120,	"DynamicRTP-Type-120" },
+	{ PT_UNDF_121,	"DynamicRTP-Type-121" },
+	{ PT_UNDF_122,	"DynamicRTP-Type-122" },
+	{ PT_UNDF_123,	"DynamicRTP-Type-123" },
+	{ PT_UNDF_124,	"DynamicRTP-Type-124" },
+	{ PT_UNDF_125,	"DynamicRTP-Type-125" },
+	{ PT_UNDF_126,	"DynamicRTP-Type-126" },
+	{ PT_UNDF_127,	"DynamicRTP-Type-127" },
+ 
 	{ 0,		NULL },
 };
 
 const value_string rtp_payload_type_short_vals[] =
 {
-       { PT_PCMU,      "g711U" },
-       { PT_1016,      "fs-1016" },
-       { PT_G721,      "g721" },
-       { PT_GSM,       "GSM" },
-       { PT_G723,      "g723" },
-       { PT_DVI4_8000, "DVI4 8k" },
-       { PT_DVI4_16000, "DVI4 16k" },
-       { PT_LPC,       "Exp. from Xerox PARC" },
-       { PT_PCMA,      "g711A" },
-       { PT_G722,      "g722" },
-       { PT_L16_STEREO, "16-bit audio, stereo" },
-       { PT_L16_MONO,  "16-bit audio, monaural" },
-       { PT_QCELP,     "Qualcomm" },
-       { PT_CN,        "CN" },
-       { PT_MPA,       "MPEG-I/II Audio"},
-       { PT_G728,      "g728" },
-       { PT_DVI4_11025, "DVI4 11k" },
-       { PT_DVI4_22050, "DVI4 22k" },
-       { PT_G729,      "g729" },
-       { PT_CN_OLD,    "CN(old)" },
-       { PT_CELB,      "CellB" },
-       { PT_JPEG,      "JPEG" },
-       { PT_NV,        "NV" },
-       { PT_H261,      "h261" },
-       { PT_MPV,       "MPEG-I/II Video"},
-       { PT_MP2T,      "MPEG-II streams"},
-       { PT_H263,      "h263" },
-       { 0,            NULL },
+	{ PT_PCMU,      "g711U" },
+	{ PT_1016,      "fs-1016" },
+	{ PT_G721,      "g721" },
+	{ PT_GSM,       "GSM" },
+	{ PT_G723,      "g723" },
+	{ PT_DVI4_8000, "DVI4 8k" },
+	{ PT_DVI4_16000, "DVI4 16k" },
+	{ PT_LPC,       "Exp. from Xerox PARC" },
+	{ PT_PCMA,      "g711A" },
+	{ PT_G722,      "g722" },
+	{ PT_L16_STEREO, "16-bit audio, stereo" },
+	{ PT_L16_MONO,  "16-bit audio, monaural" },
+	{ PT_QCELP,     "Qualcomm" },
+	{ PT_CN,        "CN" },
+	{ PT_MPA,       "MPEG-I/II Audio"},
+	{ PT_G728,      "g728" },
+	{ PT_DVI4_11025, "DVI4 11k" },
+	{ PT_DVI4_22050, "DVI4 22k" },
+	{ PT_G729,      "g729" },
+	{ PT_CN_OLD,    "CN(old)" },
+	{ PT_CELB,      "CellB" },
+	{ PT_JPEG,      "JPEG" },
+	{ PT_NV,        "NV" },
+	{ PT_H261,      "h261" },
+	{ PT_MPV,       "MPEG-I/II Video"},
+	{ PT_MP2T,      "MPEG-II streams"},
+	{ PT_H263,      "h263" },
+ 
+ 	/* Alex Lindberg - Short RTP types */
+	{ PT_UNDF_96,	"RTPType-96" },
+	{ PT_UNDF_97,	"RTPType-97" },
+	{ PT_UNDF_98,	"RTPType-98" },
+	{ PT_UNDF_99,	"RTPType-99" },
+	{ PT_UNDF_100,	"RTPType-100" },
+	{ PT_UNDF_101,	"RTPType-101" },
+	{ PT_UNDF_102,	"RTPType-102" },
+	{ PT_UNDF_103,	"RTPType-103" },
+	{ PT_UNDF_104,	"RTPType-104" },
+	{ PT_UNDF_105,	"RTPType-105" },
+	{ PT_UNDF_106,	"RTPType-106" },
+	{ PT_UNDF_107,	"RTPType-107" },
+	{ PT_UNDF_108,	"RTPType-108" },
+	{ PT_UNDF_109,	"RTPType-109" },
+	{ PT_UNDF_110,	"RTPType-110" },
+	{ PT_UNDF_111,	"RTPType-111" },
+	{ PT_UNDF_112,	"RTPType-112" },
+	{ PT_UNDF_113,	"RTPType-113" },
+	{ PT_UNDF_114,	"RTPType-114" },
+	{ PT_UNDF_115,	"RTPType-115" },
+	{ PT_UNDF_116,	"RTPType-116" },
+	{ PT_UNDF_117,	"RTPType-117" },
+	{ PT_UNDF_118,	"RTPType-118" },
+	{ PT_UNDF_119,	"RTPType-119" },
+	{ PT_UNDF_120,	"RTPType-120" },
+	{ PT_UNDF_121,	"RTPType-121" },
+	{ PT_UNDF_122,	"RTPType-122" },
+	{ PT_UNDF_123,	"RTPType-123" },
+	{ PT_UNDF_124,	"RTPType-124" },
+	{ PT_UNDF_125,	"RTPType-125" },
+	{ PT_UNDF_126,	"RTPType-126" },
+	{ PT_UNDF_127,	"RTPType-127" },
+
+	{ 0,            NULL },
 };
 #if 0
 static const value_string srtp_encryption_alg_vals[] =
@@ -374,7 +445,7 @@ rtp_free_hash_dyn_payload(GHashTable *rtp_dyn_payload)
 void srtp_add_address(packet_info *pinfo,
                      address *addr, int port,
                      int other_port,
-                     const gchar *setup_method, guint32 setup_frame_number, GHashTable *rtp_dyn_payload,
+                     const gchar *setup_method, guint32 setup_frame_number, gboolean is_video _U_, GHashTable *rtp_dyn_payload,
                      struct srtp_info *srtp_info)
 {
 	address null_addr;
@@ -444,8 +515,9 @@ void srtp_add_address(packet_info *pinfo,
 	/* Free the hash if already exists */
 	rtp_free_hash_dyn_payload(p_conv_data->rtp_dyn_payload);
 
-	g_strlcpy(p_conv_data->method, setup_method, MAX_RTP_SETUP_METHOD_SIZE);
+	g_strlcpy(p_conv_data->method, setup_method, MAX_RTP_SETUP_METHOD_SIZE+1);
 	p_conv_data->frame_number = setup_frame_number;
+	p_conv_data->is_video = is_video;
 	p_conv_data->rtp_dyn_payload = rtp_dyn_payload;
 	p_conv_data->srtp_info = srtp_info;
 }
@@ -454,9 +526,9 @@ void srtp_add_address(packet_info *pinfo,
 void rtp_add_address(packet_info *pinfo,
                      address *addr, int port,
                      int other_port,
-                     const gchar *setup_method, guint32 setup_frame_number, GHashTable *rtp_dyn_payload)
+                     const gchar *setup_method, guint32 setup_frame_number, gboolean is_video , GHashTable *rtp_dyn_payload)
 {
-	srtp_add_address(pinfo, addr, port, other_port, setup_method, setup_frame_number, rtp_dyn_payload, NULL);
+	srtp_add_address(pinfo, addr, port, other_port, setup_method, setup_frame_number, is_video, rtp_dyn_payload, NULL);
 }
 
 static gboolean
@@ -505,8 +577,8 @@ dissect_rtp_heur( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 		return FALSE;
 	}
 
-	/* Was it sent between 2 even-numbered ports? */
-	if ((pinfo->srcport % 2) || (pinfo->destport % 2)) {
+	/* Was it sent to an even-numbered port? */
+	if ((pinfo->destport % 2) != 0) {
 		return FALSE;
 	}
 
@@ -517,7 +589,8 @@ dissect_rtp_heur( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	/* Check for a sensible payload type
 	   (recognised static and preferred dynamic ranges) */
 	if ((payload_type <= PT_H263) ||
-	    (payload_type >= 96 && payload_type <= 127)) {
+		/* Alex Lindberg - Modified range to use RTP Type Names */
+	    (payload_type >= PT_UNDF_96 && payload_type <= PT_UNDF_127)) {
 		dissect_rtp( tvb, pinfo, tree );
 		return TRUE;
 	}
@@ -573,8 +646,8 @@ process_rtp_payload(tvbuff_t *newtvb, packet_info *pinfo, proto_tree *tree,
 		}
 	}
 
-	/* if the payload type is dynamic (96 to 127), we check if the conv is set and we look for the pt definition */
-	else if ( (payload_type >=96) && (payload_type <=127) ) {
+	/* if the payload type is dynamic, we check if the conv is set and we look for the pt definition */
+	else if ( (payload_type >= PT_UNDF_96 && payload_type <= PT_UNDF_127) ) {
 		if (p_conv_data && p_conv_data->rtp_dyn_payload) {
 			gchar *payload_type_str = NULL;
 			payload_type_str = g_hash_table_lookup(p_conv_data->rtp_dyn_payload, &payload_type);
@@ -1028,6 +1101,7 @@ dissect_rtp( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	rtp_info->info_padding_set = padding_set;
 	rtp_info->info_padding_count = 0;
 	rtp_info->info_marker_set = marker_set;
+	rtp_info->info_is_video = FALSE;
 	rtp_info->info_payload_type = payload_type;
 	rtp_info->info_seq_num = seq_num;
 	rtp_info->info_timestamp = timestamp;
@@ -1073,6 +1147,9 @@ dissect_rtp( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	get_conv_info(pinfo, rtp_info);
 	p_conv_data = p_get_proto_data(pinfo->fd, proto_rtp);
 
+	if (p_conv_data)
+		rtp_info->info_is_video = p_conv_data->is_video;
+
 	if (p_conv_data && p_conv_data->srtp_info) is_srtp = TRUE;
 	rtp_info->info_is_srtp = is_srtp;
 
@@ -1082,6 +1159,8 @@ dissect_rtp( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 
 	/* check if this is added as an SRTP stream - if so, don't try to dissector the payload data for now */
 	p_conv_data = p_get_proto_data(pinfo->fd, proto_rtp);
+
+		
 	if (p_conv_data && p_conv_data->srtp_info) {
 		srtp_info = p_conv_data->srtp_info;
 		if (rtp_info->info_all_data_present) {
@@ -1339,9 +1418,9 @@ static void get_conv_info(packet_info *pinfo, struct _rtp_info *rtp_info)
 
 				/* Save this conversation info into packet info */
 				p_conv_packet_data = se_alloc(sizeof(struct _rtp_conversation_info));
-				g_snprintf(p_conv_packet_data->method, MAX_RTP_SETUP_METHOD_SIZE+1, "%s", p_conv_data->method);
-				p_conv_packet_data->method[MAX_RTP_SETUP_METHOD_SIZE]='\0';
+				g_strlcpy(p_conv_packet_data->method, p_conv_data->method, MAX_RTP_SETUP_METHOD_SIZE+1);
 				p_conv_packet_data->frame_number = p_conv_data->frame_number;
+				p_conv_packet_data->is_video = p_conv_data->is_video;
 				p_conv_packet_data->rtp_dyn_payload = p_conv_data->rtp_dyn_payload;
 				p_conv_packet_data->rtp_conv_info = p_conv_data->rtp_conv_info;
 				p_conv_packet_data->srtp_info = p_conv_data->srtp_info;
