@@ -1,7 +1,7 @@
 /* packet-smtp.c
  * Routines for SMTP packet disassembly
  *
- * $Id: packet-smtp.c 26826 2008-11-23 14:18:07Z stig $
+ * $Id: packet-smtp.c 27953 2009-04-03 19:03:31Z guy $
  *
  * Copyright (c) 2000 by Richard Sharpe <rsharpe@ns.aus.com>
  *
@@ -443,7 +443,7 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             lineend = line + linelen;
             while (linep < lineend && (c = *linep) != ' ')
               linep++;
-            cmdlen = linep - line;
+            cmdlen = (int)(linep - line);
             if (line_is_smtp_command(line, cmdlen)) {
               if (g_ascii_strncasecmp(line, "DATA", 4) == 0) {
                 /*
