@@ -3,7 +3,7 @@
  * Copyright 2005, Ulf Lamping <ulf.lamping@web.de>
  * Copyright 2006-2007, Stephen Fisher <stephentfisher@yahoo.com>
  *
- * $Id: packet-vnc.c 27065 2008-12-20 00:09:02Z wmeier $
+ * $Id: packet-vnc.c 28396 2009-05-18 19:14:21Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -216,7 +216,7 @@ typedef struct {
 	guint8 security_type_selected;
 	gdouble server_proto_ver, client_proto_ver;
 	vnc_session_state_e vnc_next_state;
-
+	guint32 server_port;
 	/* These are specific to TightVNC */
 	gint num_server_message_types;
 	gint num_client_message_types;
@@ -512,6 +512,7 @@ static gint ett_vnc_colormap_color_group = -1;
 guint8 vnc_bytes_per_pixel;
 guint8 vnc_depth;
 
+static dissector_handle_t vnc_handle;
 
 /* Code to dissect the packets */
 static void
@@ -558,7 +559,7 @@ dissect_vnc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	/* First, clear the info column */
 	if(check_col(pinfo->cinfo, COL_INFO))
-                col_clear(pinfo->cinfo, COL_INFO);
+		col_clear(pinfo->cinfo, COL_INFO);
 
 	/* create display subtree for the protocol */
 	if(tree) {
@@ -576,7 +577,7 @@ dissect_vnc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	vnc_set_depth(pinfo, vnc_depth);
 
 	if(!ret) {	
-		if(DEST_PORT_VNC)
+		if(DEST_PORT_VNC || per_conversation_info->server_port == pinfo->destport)
 			vnc_client_to_server(tvb, pinfo, &offset, vnc_tree);
 		else
 			vnc_server_to_client(tvb, pinfo, &offset, vnc_tree);
@@ -631,6 +632,45 @@ process_tight_capabilities(proto_tree *tree,
 	return offset;
 }
 
+/* Returns true if this looks like a client or server version packet: 12 bytes, in the format "RFB xxx.yyy\n" .
+* Will check for the 12 bytes exact length, the 'RFB ' string and that it ends with a '\n'. 
+* The exact 'xxx.yyy' is checked later, by trying to convert it to a double using g_ascii_strtod.
+*/
+static gboolean
+vnc_is_client_or_server_version_message(tvbuff_t *tvb)
+{
+	if(tvb_length(tvb) != 12) {
+		return FALSE;
+	}
+	
+	if(tvb_strncaseeql(tvb, 0, "RFB ", 4) != 0) {
+		return FALSE;
+	}
+	/* 0x2e = '.'   0xa = '\n' */
+	if((tvb_get_guint8(tvb, 7) != 0x2e) || (tvb_get_guint8(tvb,11) != 0xa)) {
+		return FALSE;
+	}
+	
+	return TRUE;
+}
+
+static gboolean test_vnc_protocol(tvbuff_t *tvb, packet_info *pinfo,
+					proto_tree *tree)
+{
+	conversation_t *conversation;
+	
+	if (vnc_is_client_or_server_version_message(tvb)) {
+		conversation = conversation_new(pinfo->fd->num, &pinfo->src,
+										&pinfo->dst, pinfo->ptype,
+										pinfo->srcport,
+										pinfo->destport, 0);
+		conversation_set_dissector(conversation, vnc_handle);
+		dissect_vnc(tvb, pinfo, tree);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 /* Returns true if additional session startup messages follow */
 static gboolean
 vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
@@ -658,12 +698,15 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 	switch(per_packet_info->state) {
 
 	case SERVER_VERSION :
+		if (!vnc_is_client_or_server_version_message(tvb))
+			return TRUE; /* we still hope to get a SERVER_VERSION message some day. Do not proceed yet */
+			
 		proto_tree_add_item(tree, hf_vnc_server_proto_ver, tvb, 4,
-				    7, FALSE);
-
+						7, FALSE);
 		per_conversation_info->server_proto_ver =
-			g_strtod((char *)tvb_get_ephemeral_string(tvb, 4, 7),
+			g_ascii_strtod((char *)tvb_get_ephemeral_string(tvb, 4, 7),
 				 NULL);
+		per_conversation_info->server_port = pinfo->srcport;
 		
 		if (check_col(pinfo->cinfo, COL_INFO))
 			col_add_fstr(pinfo->cinfo, COL_INFO,
@@ -674,11 +717,13 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 		break;
 		
 	case CLIENT_VERSION :
+		if (!vnc_is_client_or_server_version_message(tvb))
+			return TRUE; /* we still hope to get a CLIENT_VERSION message some day. Do not proceed yet */
+		
 		proto_tree_add_item(tree, hf_vnc_client_proto_ver, tvb,
-				    4, 7, FALSE);
-
+					4, 7, FALSE);
 		per_conversation_info->client_proto_ver =
-			g_strtod((char *)tvb_get_ephemeral_string(tvb, 4, 7),
+			g_ascii_strtod((char *)tvb_get_ephemeral_string(tvb, 4, 7),
 				 NULL);
 		
 		if (check_col(pinfo->cinfo, COL_INFO))
@@ -690,44 +735,45 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 		break;
 
 	case SECURITY :
-                if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Security types supported");
+		if (check_col(pinfo->cinfo, COL_INFO))
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Security types supported");
 		
-                /* We're checking against the client protocol version because
-                 * the client is the final decider on which version to use
-                 * after the server offers the highest version it supports. */
+		/* We're checking against the client protocol version because
+		 * the client is the final decider on which version to use
+		 * after the server offers the highest version it supports. */
 		
-                if(per_conversation_info->client_proto_ver >= 3.007) {
-                        proto_tree_add_item(tree,
-                                            hf_vnc_num_security_types, tvb,
-                                            offset, 1, FALSE);
-                        num_security_types = tvb_get_guint8(tvb, offset);
-			
-                        for(offset = 1; offset <= num_security_types; offset++){
-                                proto_tree_add_item(tree,
-                                                    hf_vnc_security_type, tvb,
-                                                    offset, 1, FALSE);
+		if(per_conversation_info->client_proto_ver >= 3.007) {
+			num_security_types = tvb_get_guint8(tvb, offset);
+			if (tree) {
+				proto_tree_add_item(tree,
+					hf_vnc_num_security_types, tvb,
+					offset, 1, FALSE);
 
-                        }
-                } else {
-                        /* Version < 3.007: The server decides the
-                         * authentication type for us to use */
-                        proto_tree_add_item(tree,
-                                            hf_vnc_server_security_type, tvb,
-                                            offset, 4, FALSE);
+				for(offset = 1; offset <= num_security_types; offset++){
+					proto_tree_add_item(tree,
+						hf_vnc_security_type, tvb,
+						offset, 1, FALSE);
+				}
+			}
+		} else {
+			/* Version < 3.007: The server decides the
+			 * authentication type for us to use */
+			proto_tree_add_item(tree,
+				hf_vnc_server_security_type, tvb,
+				offset, 4, FALSE);
 		}
 
 		per_conversation_info->vnc_next_state =	SECURITY_TYPES;
 		break;
 
 	case SECURITY_TYPES :
-		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Authentication type selected by client");
-		
-                proto_tree_add_item(tree, hf_vnc_client_security_type, tvb,
-                                    offset, 1, FALSE);
+		if (check_col(pinfo->cinfo, COL_INFO)) {
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Authentication type selected by client");
+		}
+		proto_tree_add_item(tree, hf_vnc_client_security_type, tvb,
+							offset, 1, FALSE);
 		per_conversation_info->security_type_selected =
 			tvb_get_guint8(tvb, offset);
 	
@@ -761,8 +807,8 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 
 	case TIGHT_TUNNELING_CAPABILITIES :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "TightVNC tunneling capabilities supported");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "TightVNC tunneling capabilities supported");
 
 		proto_tree_add_item(tree, hf_vnc_tight_num_tunnel_types, tvb, offset, 4, FALSE);
 		num_tunnel_types = tvb_get_ntohl(tvb, offset);
@@ -796,8 +842,8 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 
 	case TIGHT_AUTH_CAPABILITIES:
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "TightVNC authentication capabilities supported");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "TightVNC authentication capabilities supported");
 
 		proto_tree_add_item(tree, hf_vnc_tight_num_auth_types, tvb, offset, 4, FALSE);
 		num_auth_types = tvb_get_ntohl(tvb, offset);
@@ -828,8 +874,8 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 
 	case TIGHT_AUTH_TYPE_AND_VENDOR_CODE :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Authentication type / vendor code");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Authentication type / vendor code");
 
 		proto_tree_add_item(tree, hf_vnc_server_security_type, tvb,
 				    offset, 4, FALSE);		
@@ -849,10 +895,10 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 		
 	case TIGHT_UNKNOWN_PACKET3 :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Unknown packet (TightVNC)");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Unknown packet (TightVNC)");
 		
-                proto_tree_add_text(tree, tvb, offset, -1,
+		proto_tree_add_text(tree, tvb, offset, -1,
 				    "Unknown packet (TightVNC)");
 
 		per_conversation_info->vnc_next_state =
@@ -862,11 +908,11 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 
 	case VNC_AUTHENTICATION_CHALLENGE :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Authentication challenge from server");
-                
-                proto_tree_add_item(tree, hf_vnc_auth_challenge, tvb,
-                                    offset, 16, FALSE);
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Authentication challenge from server");
+		
+		proto_tree_add_item(tree, hf_vnc_auth_challenge, tvb,
+				    offset, 16, FALSE);
 
 		per_conversation_info->vnc_next_state =
 			VNC_AUTHENTICATION_RESPONSE;
@@ -874,24 +920,24 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 
 	case VNC_AUTHENTICATION_RESPONSE :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Authentication response from client");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Authentication response from client");
 		
-                proto_tree_add_item(tree, hf_vnc_auth_response, tvb,
-                                    offset, 16, FALSE);
+		proto_tree_add_item(tree, hf_vnc_auth_response, tvb,
+				    offset, 16, FALSE);
 		
 		per_conversation_info->vnc_next_state = SECURITY_RESULT;
 		break;
 
 	case SECURITY_RESULT :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Authentication result");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Authentication result");
 		
-                proto_tree_add_item(tree, hf_vnc_auth_result, tvb, offset,
-                                    4, FALSE);
-                auth_result = tvb_get_ntohl(tvb, offset);
-                offset += 4;
+		proto_tree_add_item(tree, hf_vnc_auth_result, tvb, offset,
+				    4, FALSE);
+		auth_result = tvb_get_ntohl(tvb, offset);
+		offset += 4;
 
 		switch(auth_result) {
 
@@ -921,11 +967,11 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 
 	case CLIENT_INIT :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Share desktop flag");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Share desktop flag");
 
-                proto_tree_add_item(tree, hf_vnc_share_desktop_flag, tvb,
-                                    offset, 1, FALSE);
+		proto_tree_add_item(tree, hf_vnc_share_desktop_flag, tvb,
+				    offset, 1, FALSE);
 		
 		per_conversation_info->vnc_next_state = SERVER_INIT;
 
@@ -933,74 +979,74 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 		
 	case SERVER_INIT :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "Server framebuffer parameters");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "Server framebuffer parameters");
 	       
-                proto_tree_add_item(tree, hf_vnc_width, tvb, offset, 2,
-                                    FALSE);
-                offset += 2;
+		proto_tree_add_item(tree, hf_vnc_width, tvb, offset, 2,
+				    FALSE);
+		offset += 2;
 
-                proto_tree_add_item(tree, hf_vnc_height, tvb, offset, 2,
-                                    FALSE);
-                offset += 2;
+		proto_tree_add_item(tree, hf_vnc_height, tvb, offset, 2,
+				    FALSE);
+		offset += 2;
 
-                proto_tree_add_item(tree, hf_vnc_server_bits_per_pixel,
-                                    tvb, offset, 1, FALSE);
-                vnc_bytes_per_pixel = tvb_get_guint8(tvb, offset)/8;
-                vnc_set_bytes_per_pixel(pinfo, vnc_bytes_per_pixel);
-                offset += 1;
+		proto_tree_add_item(tree, hf_vnc_server_bits_per_pixel,
+				    tvb, offset, 1, FALSE);
+		vnc_bytes_per_pixel = tvb_get_guint8(tvb, offset)/8;
+		vnc_set_bytes_per_pixel(pinfo, vnc_bytes_per_pixel);
+		offset += 1;
 
-                proto_tree_add_item(tree, hf_vnc_server_depth, tvb, offset,
-                                    1, FALSE);
-                offset += 1;
+		proto_tree_add_item(tree, hf_vnc_server_depth, tvb, offset,
+				    1, FALSE);
+		offset += 1;
 
-                proto_tree_add_item(tree, hf_vnc_server_big_endian_flag,
-                                    tvb, offset, 1, FALSE);
-                offset += 1;
+		proto_tree_add_item(tree, hf_vnc_server_big_endian_flag,
+				    tvb, offset, 1, FALSE);
+		offset += 1;
 
-                proto_tree_add_item(tree, hf_vnc_server_true_color_flag,
-                                    tvb, offset, 1, FALSE);
-                offset += 1;
+		proto_tree_add_item(tree, hf_vnc_server_true_color_flag,
+				    tvb, offset, 1, FALSE);
+		offset += 1;
 
-                proto_tree_add_item(tree, hf_vnc_server_red_max,
-                                    tvb, offset, 2, FALSE);
-                offset += 2;
+		proto_tree_add_item(tree, hf_vnc_server_red_max,
+				    tvb, offset, 2, FALSE);
+		offset += 2;
 
-                proto_tree_add_item(tree, hf_vnc_server_green_max,
-                                    tvb, offset, 2, FALSE);
-                offset += 2;
+		proto_tree_add_item(tree, hf_vnc_server_green_max,
+				    tvb, offset, 2, FALSE);
+		offset += 2;
 
-                proto_tree_add_item(tree, hf_vnc_server_blue_max,
-                                    tvb, offset, 2, FALSE);
-                offset += 2;
+		proto_tree_add_item(tree, hf_vnc_server_blue_max,
+				    tvb, offset, 2, FALSE);
+		offset += 2;
 
-                proto_tree_add_item(tree, hf_vnc_server_red_shift,
-                                    tvb, offset, 1, FALSE);
-                offset += 1;
+		proto_tree_add_item(tree, hf_vnc_server_red_shift,
+				    tvb, offset, 1, FALSE);
+		offset += 1;
 
-                proto_tree_add_item(tree, hf_vnc_server_green_shift,
-                                    tvb, offset, 1, FALSE);
-                offset += 1;
+		proto_tree_add_item(tree, hf_vnc_server_green_shift,
+				    tvb, offset, 1, FALSE);
+		offset += 1;
 
-                proto_tree_add_item(tree, hf_vnc_server_blue_shift,
-                                    tvb, offset, 1, FALSE);
-                offset += 1;
+		proto_tree_add_item(tree, hf_vnc_server_blue_shift,
+				    tvb, offset, 1, FALSE);
+		offset += 1;
 
-                proto_tree_add_item(tree, hf_vnc_padding,
-                                    tvb, offset, 3, FALSE);
-                offset += 3; /* Skip over 3 bytes of padding */
-                
-                if(tvb_length_remaining(tvb, offset) > 0) {
-                        /* Sometimes the desktop name & length is skipped */
-                        proto_tree_add_item(tree, hf_vnc_desktop_name_len,
-                                            tvb, offset, 4, FALSE);
-                        desktop_name_len = tvb_get_ntohl(tvb, offset);
-                        offset += 4;
+		proto_tree_add_item(tree, hf_vnc_padding,
+				    tvb, offset, 3, FALSE);
+		offset += 3; /* Skip over 3 bytes of padding */
+		
+		if(tvb_length_remaining(tvb, offset) > 0) {
+			/* Sometimes the desktop name & length is skipped */
+			proto_tree_add_item(tree, hf_vnc_desktop_name_len,
+					    tvb, offset, 4, FALSE);
+			desktop_name_len = tvb_get_ntohl(tvb, offset);
+			offset += 4;
 
-                        proto_tree_add_item(tree, hf_vnc_desktop_name,
-                                            tvb, offset, desktop_name_len,
-                                            FALSE);
-                }
+			proto_tree_add_item(tree, hf_vnc_desktop_name,
+					    tvb, offset, desktop_name_len,
+					    FALSE);
+		}
 
 		if(per_conversation_info->security_type_selected == TIGHT)
 			per_conversation_info->vnc_next_state =
@@ -1011,8 +1057,8 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 		
 	case TIGHT_INTERACTION_CAPS :
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "TightVNC Interaction Capabilities");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "TightVNC Interaction Capabilities");
 
 		proto_tree_add_item(tree, hf_vnc_num_server_message_types,
 				    tvb, offset, 2, FALSE);
@@ -1038,8 +1084,8 @@ vnc_startup_messages(tvbuff_t *tvb, packet_info *pinfo, gint offset,
 
 	case TIGHT_INTERACTION_CAPS_LIST:
 		if (check_col(pinfo->cinfo, COL_INFO))
-                        col_set_str(pinfo->cinfo, COL_INFO,
-                                    "TightVNC Interaction Capabilities list");
+			col_set_str(pinfo->cinfo, COL_INFO,
+				    "TightVNC Interaction Capabilities list");
 
 		offset = process_tight_capabilities(tree,
 						    hf_vnc_tight_server_message_type,
@@ -1788,10 +1834,9 @@ vnc_zrle_encoding(tvbuff_t *tvb, packet_info *pinfo _U_, gint *offset,
 			    data_len, FALSE);
 
 #ifdef HAVE_LIBZ
-	uncomp_tvb = tvb_uncompress(tvb, *offset, data_len);
+	uncomp_tvb = tvb_child_uncompress(tvb, tvb, *offset, data_len);
 
 	if(uncomp_tvb != NULL) {
-		tvb_set_child_real_data_tvbuff(tvb, uncomp_tvb);
 		add_new_data_source(pinfo, uncomp_tvb,
 				    "Uncompressed ZRLE data");
 
@@ -2274,18 +2319,18 @@ proto_register_vnc(void)
 	module_t *vnc_module; /* To handle our preferences */
 
 	/* Setup list of header fields */
-        static hf_register_info hf[] = {
+	static hf_register_info hf[] = {
 		{ &hf_vnc_padding,
 		  { "Padding", "vnc.padding",
 		    FT_NONE, BASE_NONE, NULL, 0x0,
 		    "Unused space", HFILL }
 		},
 
-                { &hf_vnc_server_proto_ver,
+		{ &hf_vnc_server_proto_ver,
 		  { "Server protocol version", "vnc.server_proto_ver",
 		    FT_STRING, BASE_NONE, NULL, 0x0,
 		    "VNC protocol version on server", HFILL }
-                },
+		},
 		{ &hf_vnc_client_proto_ver,
 		  { "Client protocol version", "vnc.client_proto_ver",
 		    FT_STRING, BASE_NONE, NULL, 0x0,
@@ -2684,7 +2729,7 @@ proto_register_vnc(void)
 		/* Client Framebuffer Update Request */
 		{ &hf_vnc_update_req_incremental,
 		  { "Incremental update", "vnc.update_req_incremental",
-		    FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+		    FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 		    "Specifies if the client wants an incremental update instead of a full one", HFILL }
 		},
 		{ &hf_vnc_update_req_x_pos,
@@ -3051,7 +3096,7 @@ void
 proto_reg_handoff_vnc(void)
 {
 	static gboolean inited = FALSE;
-	static dissector_handle_t vnc_handle;
+
 	/* This is a behind the scenes variable that is not changed by the user.
 	 * This stores last setting of the vnc_preference_alternate_port.  Used to keep
 	 * track of when the user has changed the setting so that we can delete
@@ -3065,7 +3110,8 @@ proto_reg_handoff_vnc(void)
 		dissector_add("tcp.port", 5501, vnc_handle);
 		dissector_add("tcp.port", 5900, vnc_handle);
 		dissector_add("tcp.port", 5901, vnc_handle);
-
+		
+		heur_dissector_add("tcp", test_vnc_protocol, proto_vnc);
 		/* We don't register a port for the VNC HTTP server because
 		 * that simply provides a java program for download via the
 		 * HTTP protocol.  The java program then connects to a standard
@@ -3094,5 +3140,6 @@ proto_reg_handoff_vnc(void)
 					      vnc_handle);
 			}
 		}
+		heur_dissector_add("tcp", test_vnc_protocol, proto_vnc);
 	}
 }
