@@ -1,6 +1,6 @@
 /* follow.c
  *
- * $Id: follow.c 26306 2008-09-30 13:29:15Z sake $
+ * $Id: follow.c 27984 2009-04-07 16:36:52Z gerald $
  *
  * Copyright 1998 Mike Hall <mlh@io.com>
  *
@@ -384,7 +384,7 @@ check_fragments( int index, tcp_stream_chunk *sc, gulong acknowledged ) {
        */
       dummy_str = g_strdup_printf("[%d bytes missing in capture file]",
                         (int)(lowest_seq - seq[index]) );
-      sc->dlen = strlen(dummy_str);
+      sc->dlen = (guint32) strlen(dummy_str);
       write_packet_data( index, sc, dummy_str );
       g_free(dummy_str);
       seq[index] = lowest_seq;
@@ -424,8 +424,14 @@ reset_tcp_reassembly(void)
 static void
 write_packet_data( int index, tcp_stream_chunk *sc, const char *data )
 {
-  DISSECTOR_ASSERT(1 * sizeof(tcp_stream_chunk) == fwrite( sc, 1, sizeof(tcp_stream_chunk), data_out_file ));
-  DISSECTOR_ASSERT(1 * sc->dlen == fwrite( data, 1, sc->dlen, data_out_file ));
+  size_t ret;
+
+  ret = fwrite( sc, 1, sizeof(tcp_stream_chunk), data_out_file );
+  DISSECTOR_ASSERT(sizeof(tcp_stream_chunk) == ret);
+  
+  ret = fwrite( data, 1, sc->dlen, data_out_file );
+  DISSECTOR_ASSERT(sc->dlen == ret);
+
   bytes_written[index] += sc->dlen;
   empty_tcp_stream = FALSE;
 }
