@@ -1,7 +1,7 @@
 /* strutil.h
  * String utility definitions
  *
- * $Id: strutil.h 25192 2008-04-29 08:44:57Z guy $
+ * $Id: strutil.h 27891 2009-03-30 03:40:12Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -62,9 +62,9 @@ int        get_token_len(const guchar *linep, const guchar *lineend,
  *
  * @see tvb_format_text()
  */
-gchar*     format_text(const guchar *line, int len);
+gchar*     format_text(const guchar *line, size_t len);
 
-gchar*     format_text_wsp(const guchar *line, int len);
+gchar*     format_text_wsp(const guchar *line, size_t len);
 
 /** Turn an array of bytes into a string showing the bytes in hex.
  *
@@ -215,4 +215,11 @@ char * convert_string_case(const char *string, gboolean case_insensitive);
  */
 char * epan_strcasestr(const char *haystack, const char *needle);
 
+/** Guarantee a non-null string.
+ *
+ * @param string The string to check
+ * @return A pointer 'string' if it's non-null, otherwise "[NULL]".
+ */
+const char * string_or_null(const char *string);
+
 #endif /* __STRUTIL_H__ */
