@@ -9,7 +9,7 @@
  * 		the data of a backing tvbuff, or can be a composite of
  * 		other tvbuffs.
  *
- * $Id: tvbuff.c 27718 2009-03-13 22:06:48Z stig $
+ * $Id: tvbuff.c 28140 2009-04-24 08:08:37Z stig $
  *
  * Copyright (c) 2000 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -299,6 +299,17 @@ tvb_new_real_data(const guint8* data, guint length, gint reported_length)
 	return tvb;
 }
 
+tvbuff_t*
+tvb_new_child_real_data(tvbuff_t *parent, const guint8* data, guint length, gint reported_length)
+{
+	tvbuff_t *tvb = tvb_new_real_data(data, length, reported_length);
+	if (tvb) {
+		tvb_set_child_real_data_tvbuff (parent, tvb);
+	}
+	
+	return tvb;
+}
+
 /* Computes the absolute offset and length based on a possibly-negative offset
  * and a length that is possible -1 (which means "to the end of the data").
  * Returns TRUE/FALSE indicating whether the offset is in bounds or
@@ -938,7 +949,7 @@ guint8_pbrk(const guint8* haystack, size_t haystacklen, const guint8 *needles)
 /************** ACCESSORS **************/
 
 static void*
-composite_memcpy(tvbuff_t *tvb, guint8* target, guint abs_offset, guint abs_length)
+composite_memcpy(tvbuff_t *tvb, guint8* target, guint abs_offset, size_t abs_length)
 {
 	guint		i, num_members;
 	tvb_comp_t	*composite;
@@ -964,7 +975,7 @@ composite_memcpy(tvbuff_t *tvb, guint8* target, guint abs_offset, guint abs_leng
 	DISSECTOR_ASSERT(member_tvb);
 
 	if (check_offset_length_no_exception(member_tvb, abs_offset - composite->start_offsets[i],
-				abs_length, &member_offset, &member_length, NULL)) {
+				(gint) abs_length, &member_offset, &member_length, NULL)) {
 
 		DISSECTOR_ASSERT(!tvb->real_data);
 		return tvb_memcpy(member_tvb, target, member_offset, member_length);
@@ -996,12 +1007,23 @@ composite_memcpy(tvbuff_t *tvb, guint8* target, guint abs_offset, guint abs_leng
 }
 
 void*
-tvb_memcpy(tvbuff_t *tvb, void* target, gint offset, gint length)
+tvb_memcpy(tvbuff_t *tvb, void* target, gint offset, size_t length)
 {
 	guint	abs_offset, abs_length;
 
-	DISSECTOR_ASSERT(length >= -1);
-	check_offset_length(tvb, offset, length, &abs_offset, &abs_length);
+	/*
+	 * XXX - we should eliminate the "length = -1 means 'to the end
+	 * of the tvbuff'" convention, and use other means to achieve
+	 * that; this would let us eliminate a bunch of checks for
+	 * negative lengths in cases where the protocol has a 32-bit
+	 * length field.
+	 *
+	 * Allowing -1 but throwing an assertion on other negative
+	 * lengths is a bit more work with the length being a size_t;
+	 * instead, we check for a length <= 2^31-1.
+	 */
+	DISSECTOR_ASSERT(length <= 0x7FFFFFFF);
+	check_offset_length(tvb, offset, (gint) length, &abs_offset, &abs_length);
 
 	if (tvb->real_data) {
 		return memcpy(target, tvb->real_data + abs_offset, abs_length);
@@ -1036,12 +1058,12 @@ tvb_memcpy(tvbuff_t *tvb, void* target, gint offset, gint length)
  * meaning "to the end of the buffer"?
  */
 void*
-tvb_memdup(tvbuff_t *tvb, gint offset, gint length)
+tvb_memdup(tvbuff_t *tvb, gint offset, size_t length)
 {
 	guint	abs_offset, abs_length;
 	void	*duped;
 
-	check_offset_length(tvb, offset, length, &abs_offset, &abs_length);
+	check_offset_length(tvb, offset, (gint) length, &abs_offset, &abs_length);
 
 	duped = g_malloc(abs_length);
 	return tvb_memcpy(tvb, duped, abs_offset, abs_length);
@@ -1064,12 +1086,12 @@ tvb_memdup(tvbuff_t *tvb, gint offset, gint length)
  * after the current packet has been dissected.
  */
 void*
-ep_tvb_memdup(tvbuff_t *tvb, gint offset, gint length)
+ep_tvb_memdup(tvbuff_t *tvb, gint offset, size_t length)
 {
 	guint	abs_offset, abs_length;
 	void	*duped;
 
-	check_offset_length(tvb, offset, length, &abs_offset, &abs_length);
+	check_offset_length(tvb, offset, (gint) length, &abs_offset, &abs_length);
 
 	duped = ep_alloc(abs_length);
 	return tvb_memcpy(tvb, duped, abs_offset, abs_length);
@@ -1732,7 +1754,7 @@ tvb_find_guint8(tvbuff_t *tvb, gint offset, gint maxlength, guint8 needle)
 			return -1;
 		}
 		else {
-			return result - tvb->real_data;
+			return (gint) (result - tvb->real_data);
 		}
 	}
 
@@ -1795,7 +1817,7 @@ tvb_pbrk_guint8(tvbuff_t *tvb, gint offset, gint maxlength, const guint8 *needle
 			return -1;
 		}
 		else {
-			return result - tvb->real_data;
+			return (gint) (result - tvb->real_data);
 		}
 	}
 
@@ -1935,11 +1957,11 @@ tvb_strncaseeql(tvbuff_t *tvb, gint offset, const gchar *str, gint size)
  * it returns 0 (meaning "equal") and -1 otherwise, otherwise return -1.
  */
 gint
-tvb_memeql(tvbuff_t *tvb, gint offset, const guint8 *str, gint size)
+tvb_memeql(tvbuff_t *tvb, gint offset, const guint8 *str, size_t size)
 {
 	const guint8 *ptr;
 
-	ptr = ensure_contiguous_no_exception(tvb, offset, size, NULL);
+	ptr = ensure_contiguous_no_exception(tvb, offset, (gint) size, NULL);
 
 	if (ptr) {
 		int cmp = memcmp(ptr, str, size);
@@ -2089,6 +2111,30 @@ tvb_format_stringzpad(tvbuff_t *tvb, gint offset, gint size)
 
 }
 
+/*
+ * Like "tvb_format_text_wsp()", but for null-padded strings; don't show
+ * the null padding characters as "\000".
+ */
+gchar *
+tvb_format_stringzpad_wsp(tvbuff_t *tvb, gint offset, gint size)
+{
+  const guint8 *ptr, *p;
+  gint len = size;
+  gint stringlen;
+
+  if ((ptr = ensure_contiguous(tvb, offset, size)) == NULL) {
+
+    len = tvb_length_remaining(tvb, offset);
+    ptr = ensure_contiguous(tvb, offset, len);
+
+  }
+
+  for (p = ptr, stringlen = 0; stringlen < len && *p != '\0'; p++, stringlen++)
+    ;
+  return format_text_wsp(ptr, stringlen);
+
+}
+
 /*
  * Given a tvbuff, an offset, and a length, allocate a buffer big enough
  * to hold a non-null-terminated string of that length at that offset,
@@ -2144,6 +2190,34 @@ tvb_get_ephemeral_string(tvbuff_t *tvb, gint offset, gint length)
 	return strbuf;
 }
 
+/*
+ * Given a tvbuff, an offset, and a length, allocate a buffer big enough
+ * to hold a non-null-terminated string of that length at that offset,
+ * plus a trailing '\0', copy the string into it, and return a pointer
+ * to the string.
+ *
+ * Throws an exception if the tvbuff ends before the string does.
+ *
+ * This function allocates memory from a buffer with capture session lifetime.
+ * You do not have to free this buffer, it will be automatically freed
+ * when wireshark starts or opens a new capture.
+ */
+guint8 *
+tvb_get_seasonal_string(tvbuff_t *tvb, gint offset, gint length)
+{
+	const guint8 *ptr;
+	guint8 *strbuf = NULL;
+
+	tvb_ensure_bytes_exist(tvb, offset, length);
+
+	ptr = ensure_contiguous(tvb, offset, length);
+	strbuf = se_alloc(length + 1);
+	if (length != 0) {
+		memcpy(strbuf, ptr, length);
+	}
+	strbuf[length] = '\0';
+	return strbuf;
+}
 
 /*
  * Given a tvbuff and an offset, with the offset assumed to refer to
@@ -2192,6 +2266,31 @@ tvb_get_ephemeral_stringz(tvbuff_t *tvb, gint offset, gint *lengthp)
 	return strptr;
 }
 
+/*
+ * Given a tvbuff and an offset, with the offset assumed to refer to
+ * a null-terminated string, find the length of that string (and throw
+ * an exception if the tvbuff ends before we find the null), allocate
+ * a buffer big enough to hold the string, copy the string into it,
+ * and return a pointer to the string.  Also return the length of the
+ * string (including the terminating null) through a pointer.
+ *
+ * This function allocates memory from a buffer with capture session lifetime.
+ * You do not have to free this buffer, it will be automatically freed
+ * when wireshark starts or opens a new capture.
+ */
+guint8 *
+tvb_get_seasonal_stringz(tvbuff_t *tvb, gint offset, gint *lengthp)
+{
+	guint size;
+	guint8 *strptr;
+
+	size = tvb_strsize(tvb, offset);
+	strptr = se_alloc(size);
+	tvb_memcpy(tvb, strptr, offset, size);
+	*lengthp = size;
+	return strptr;
+}
+
 /* Looks for a stringz (NUL-terminated string) in tvbuff and copies
  * no more than bufsize number of bytes, including terminating NUL, to buffer.
  * Returns length of string (not including terminating NUL), or -1 if the string was
@@ -2678,7 +2777,7 @@ tvb_find_tvb(tvbuff_t *haystack_tvb, tvbuff_t *needle_tvb, gint haystack_offset)
 			needle_data, needle_len);
 
 	if (location) {
-		return location - haystack_data;
+		return (gint) (location - haystack_data);
 	}
 	else {
 		return -1;
@@ -2919,7 +3018,7 @@ tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 				g_free(strmbuf);
 				return NULL;
 			}
-			comprlen -= (c - compr);
+			comprlen -= (int) (c - compr);
 
 			inflateEnd(strm);
 			err = inflateInit2(strm, wbits);
@@ -2993,3 +3092,12 @@ tvb_uncompress(tvbuff_t *tvb _U_, int offset _U_, int comprlen _U_)
 }
 #endif
 
+tvbuff_t* tvb_child_uncompress(tvbuff_t *parent _U_, tvbuff_t *tvb, int offset, int comprlen)
+{
+	tvbuff_t *new_tvb = tvb_uncompress(tvb, offset, comprlen);
+	if (new_tvb)
+		tvb_set_child_real_data_tvbuff (parent, new_tvb);
+	return new_tvb;
+}
+
+
