@@ -5,7 +5,7 @@
  *
  * MUCH code modified from service_response_time_table.c.
  *
- * $Id: ansi_a_stat.c 27741 2009-03-16 18:01:25Z etxrab $
+ * $Id: ansi_a_stat.c 29099 2009-07-15 00:10:08Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -195,7 +195,7 @@ ansi_a_stat_gtk_win_destroy_cb(
 
 /* Create list */
 static
-GtkWidget* create_list()
+GtkWidget* create_list(void)
 {
 
     GtkListStore *list_store;
@@ -295,7 +295,9 @@ ansi_a_stat_gtk_win_create(
     GtkWidget		*bbox;
 
 
-    dlg_p->win = window_new(GTK_WINDOW_TOPLEVEL, title);
+	dlg_p->win= dlg_window_new(title);  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(dlg_p->win), TRUE);
+
     gtk_window_set_default_size(GTK_WINDOW(dlg_p->win), 480, 450);
 
     vbox=gtk_vbox_new(FALSE, 3);
