@@ -7,7 +7,7 @@
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com> and
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: dfilter_expr_dlg.c 27718 2009-03-13 22:06:48Z stig $
+ * $Id: dfilter_expr_dlg.c 29102 2009-07-15 19:22:21Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -189,13 +189,12 @@ field_select_row_cb(GtkTreeSelection *sel, gpointer tree)
     case FT_INT24:
     case FT_INT32:
         /*
-         * If this has a value_string table associated with it,
-         * fill up the list of values, otherwise clear the list
-         * of values.
+         * If this has a value_string table (not a range_string table) associated with it,
+         * fill up the list of values, otherwise clear the list of values.
          */
-        if (hfinfo->strings != NULL) {
-            build_enum_values(value_list_scrolled_win, value_list,
-                              hfinfo->strings);
+	/* XXX: ToDo: Implement "range-string" filter ?   */
+        if ((hfinfo->strings != NULL) & !(hfinfo->display & BASE_RANGE_STRING)) {
+            build_enum_values(value_list_scrolled_win, value_list, hfinfo->strings);
         } else
             gtk_list_store_clear(GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(value_list))));
         break;
@@ -425,7 +424,7 @@ static void
 display_value_fields(header_field_info *hfinfo, gboolean is_comparison,
                      GtkWidget *value_label, GtkWidget *value_entry,
                      GtkWidget *value_list_label,
-                     GtkWidget  *value_list _U_,
+                     GtkWidget *value_list _U_,
                      GtkWidget *value_list_scrolled_win, GtkWidget *range_label,
                      GtkWidget *range_entry)
 {
@@ -484,7 +483,7 @@ display_value_fields(header_field_info *hfinfo, gboolean is_comparison,
 	case FT_INT16:
 	case FT_INT24:
 	case FT_INT32:
-		if (hfinfo->strings != NULL) {
+		if ((hfinfo->strings != NULL) && !(hfinfo->display & BASE_RANGE_STRING)) {
 			/*
 			 * We have a list of values to show.
 			 */
@@ -539,7 +538,7 @@ value_list_sel_cb(GtkTreeSelection *sel, gpointer value_entry_arg)
     header_field_info *hfinfo = g_object_get_data(G_OBJECT(window),
                                                 E_DFILTER_EXPR_CURRENT_VAR_KEY);
     const value_string *value = NULL;
-    char value_string[11+1];	/* long enough for 32-bit octal value */
+    gchar *value_display_string = NULL;
 
     if (!gtk_tree_selection_get_selected(sel, &model, &iter))
         return;
@@ -557,16 +556,16 @@ value_list_sel_cb(GtkTreeSelection *sel, gpointer value_entry_arg)
          * testing for "false".
          */
         if (value != NULL)
-		g_snprintf(value_string, sizeof value_string, "1");
+		value_display_string = g_strdup("1");
         else
-		g_snprintf(value_string, sizeof value_string, "0");
+		value_display_string = g_strdup("0");
     } else {
         /*
          * Numeric type; get the value corresponding to the
          * selected item, and display it in the base for this
          * field.
          */
-        switch (hfinfo->display) {
+        switch ((hfinfo->display) & BASE_STRUCTURE_RESET) {
 
         case BASE_NONE:
         case BASE_DEC:
@@ -576,16 +575,14 @@ value_list_sel_cb(GtkTreeSelection *sel, gpointer value_entry_arg)
             case FT_UINT16:
             case FT_UINT24:
             case FT_UINT32:
-                g_snprintf(value_string, sizeof value_string,
-                         "%u", value->value);
+                value_display_string = g_strdup_printf("%u", value->value);
                 break;
 
             case FT_INT8:
             case FT_INT16:
             case FT_INT24:
             case FT_INT32:
-                g_snprintf(value_string, sizeof value_string,
-                         "%d", value->value);
+                value_display_string = g_strdup_printf("%d", value->value);
                 break;
 
             default:
@@ -594,20 +591,20 @@ value_list_sel_cb(GtkTreeSelection *sel, gpointer value_entry_arg)
             break;
 
         case BASE_HEX:
-            g_snprintf(value_string, sizeof value_string, "0x%x",
-                     value->value);
+            value_display_string = g_strdup_printf("0x%x", value->value);
             break;
 
         case BASE_OCT:
-            g_snprintf(value_string, sizeof value_string, "%#o",
-                     value->value);
+            value_display_string = g_strdup_printf("%#o", value->value);
             break;
 
         default:
             g_assert_not_reached();
         }
     }
-    gtk_entry_set_text(GTK_ENTRY(value_entry), value_string);
+
+    gtk_entry_set_text(GTK_ENTRY(value_entry), value_display_string);
+    g_free (value_display_string);
 }
 
 static void
@@ -802,18 +799,18 @@ dfilter_expr_dlg_accept_cb(GtkWidget *w, gpointer filter_te_arg)
     g_free(chars);
 
     gtk_editable_insert_text(GTK_EDITABLE(filter_te), hfinfo->abbrev,
-                             strlen(hfinfo->abbrev), &pos);
+                             (gint) strlen(hfinfo->abbrev), &pos);
     if (range_str != NULL) {
         gtk_editable_insert_text(GTK_EDITABLE(filter_te), "[", 1, &pos);
         gtk_editable_insert_text(GTK_EDITABLE(filter_te),
-                                 stripped_range_str, strlen(stripped_range_str), &pos);
+                                 stripped_range_str, (gint) strlen(stripped_range_str), &pos);
         gtk_editable_insert_text(GTK_EDITABLE(filter_te), "]", 1, &pos);
         g_free(range_str);
     }
     if (item_str != NULL && !relation_is_presence_test(item_str)) {
         gtk_editable_insert_text(GTK_EDITABLE(filter_te), " ", 1, &pos);
         gtk_editable_insert_text(GTK_EDITABLE(filter_te), item_str,
-                                 strlen(item_str), &pos);
+                                 (gint) strlen(item_str), &pos);
     }
     if (value_str != NULL) {
         gtk_editable_insert_text(GTK_EDITABLE(filter_te), " ", 1, &pos);
@@ -849,7 +846,7 @@ dfilter_expr_dlg_accept_cb(GtkWidget *w, gpointer filter_te_arg)
                                      1, &pos);
         }
         gtk_editable_insert_text(GTK_EDITABLE(filter_te),
-                                 stripped_value_str, strlen(stripped_value_str), &pos);
+                                 stripped_value_str, (gint) strlen(stripped_value_str), &pos);
         if (quote_it) {
             /*
              * Put quotes around the string.
@@ -960,7 +957,7 @@ dfilter_expr_dlg_new(GtkWidget *filter_te)
     gtk_container_add(GTK_CONTAINER(main_hb), field_vb);
 
     field_tree_lb = gtk_label_new("Field name");
-    gtk_misc_set_alignment(GTK_MISC(field_tree_lb), 0.0, 0.0);
+    gtk_misc_set_alignment(GTK_MISC(field_tree_lb), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(field_vb), field_tree_lb, FALSE, FALSE, 0);
 
     tree_scrolled_win = scrolled_window_new(NULL, NULL);
@@ -989,7 +986,7 @@ dfilter_expr_dlg_new(GtkWidget *filter_te)
     gtk_container_add(GTK_CONTAINER(main_hb), relation_vb);
 
     relation_label = gtk_label_new("Relation");
-    gtk_misc_set_alignment(GTK_MISC(relation_label), 0.0, 0.0);
+    gtk_misc_set_alignment(GTK_MISC(relation_label), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(relation_vb), relation_label, FALSE, FALSE, 0);
 
     relation_list_scrolled_win = scrolled_window_new(NULL, NULL);
@@ -1064,14 +1061,14 @@ dfilter_expr_dlg_new(GtkWidget *filter_te)
     gtk_container_add(GTK_CONTAINER(main_hb), value_vb);
 
     value_label = gtk_label_new("Value");
-    gtk_misc_set_alignment(GTK_MISC(value_label), 0.0, 0.0);
+    gtk_misc_set_alignment(GTK_MISC(value_label), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(value_vb), value_label, FALSE, FALSE, 0);
 
     value_entry = gtk_entry_new();
     gtk_box_pack_start(GTK_BOX(value_vb), value_entry, FALSE, FALSE, 0);
 
     value_list_label = gtk_label_new("Predefined values:");
-    gtk_misc_set_alignment(GTK_MISC(value_list_label), 0.0, 0.0);
+    gtk_misc_set_alignment(GTK_MISC(value_list_label), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(value_vb), value_list_label, FALSE, FALSE, 0);
 
     value_list_scrolled_win = scrolled_window_new(NULL, NULL);
@@ -1131,7 +1128,6 @@ dfilter_expr_dlg_new(GtkWidget *filter_te)
 	g_snprintf(str, TAG_STRING_LEN, "%s - %s", 
 		   proto_get_protocol_short_name(protocol),
 		   proto_get_protocol_long_name(protocol));
-	str[TAG_STRING_LEN]='\0';
 	strp=str;
 
 	hfinfo = proto_registrar_get_nth(i);
@@ -1152,7 +1148,6 @@ dfilter_expr_dlg_new(GtkWidget *filter_te)
                 g_snprintf(str, TAG_STRING_LEN, "%s - %s", hfinfo->abbrev,
                            hfinfo->name);
             }
-            str[TAG_STRING_LEN]='\0';
             gtk_tree_store_append(store, &child_iter, &iter);
             gtk_tree_store_set(store, &child_iter, 0, strp, 1, hfinfo, -1);
 	}
@@ -1161,7 +1156,7 @@ dfilter_expr_dlg_new(GtkWidget *filter_te)
 }
 
     range_label = gtk_label_new("Range (offset:length)");
-    gtk_misc_set_alignment(GTK_MISC(range_label), 0.0, 0.0);
+    gtk_misc_set_alignment(GTK_MISC(range_label), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(value_vb), range_label, FALSE, FALSE, 0);
 
     range_entry = gtk_entry_new();
