@@ -1,5 +1,5 @@
 /* flow_graph.c
- * $Id: flow_graph.c 26094 2008-08-26 02:53:21Z wmeier $
+ * $Id: flow_graph.c 29099 2009-07-15 00:10:08Z gerald $
  * Allows to display a flow graph of the currently displayed packets
  *
  * Copyright 2004, Ericsson , Spain
@@ -249,13 +249,10 @@ static int flow_graph_frame_add_to_graph(packet_info *pinfo)
 	gai->comment=NULL;
 	gai->frame_label=NULL;
 
-	if (gai->comment!=NULL){
-		g_free(gai->comment);
-	}
-	if (gai->frame_label!=NULL){
-		g_free(gai->frame_label);
-	}
-
+	/* this code doesn't make sense.
+	g_free(gai->comment);
+	g_free(gai->frame_label);
+	*/
 
 	if(pinfo->cinfo) {
 		if (pinfo->cinfo->col_first[COL_INFO]>=0){
@@ -263,6 +260,7 @@ static int flow_graph_frame_add_to_graph(packet_info *pinfo)
 			for (i = pinfo->cinfo->col_first[COL_INFO]; i <= pinfo->cinfo->col_last[COL_INFO]; i++) {
 				if (pinfo->cinfo->fmt_matx[i][COL_INFO]) {
 					colinfo = g_strdup(pinfo->cinfo->col_data[i]);
+					/* break; ? or g_free(colinfo); before g_strdup() */
 				}
 			}
 		}
@@ -272,7 +270,7 @@ static int flow_graph_frame_add_to_graph(packet_info *pinfo)
 			for (i = pinfo->cinfo->col_first[COL_PROTOCOL]; i <= pinfo->cinfo->col_last[COL_PROTOCOL]; i++) {
 				if (pinfo->cinfo->fmt_matx[i][COL_PROTOCOL]) {
 					protocol = g_strdup(pinfo->cinfo->col_data[i]);
-
+					/* break; ? or g_free(protocol); before g_strdup() */
 				}
 			}
 		}
@@ -291,18 +289,11 @@ static int flow_graph_frame_add_to_graph(packet_info *pinfo)
 		if (protocol != NULL) {
 			gai->frame_label = g_strdup_printf("%.19s", protocol);
 			gai->comment = g_strdup_printf("%s", protocol);
-		} else {
-			gai->frame_label = NULL;
-			gai->comment = NULL;
 		}
 	}
 
-	if (protocol!=NULL){
-		g_free(protocol);
-	}
-	if (colinfo!=NULL){
-		g_free(colinfo);
-	}
+	g_free(protocol);
+	g_free(colinfo);
 
 	gai->line_style=1;
 	gai->conv_num=0;
@@ -343,14 +334,14 @@ static int flow_graph_tcp_add_to_graph(packet_info *pinfo, const struct tcpheade
     bpos = 1 << i;
     if (tcph->th_flags & bpos) {
       if (flags_found) {
-        g_strlcat(flags, ", ", 64);
+        g_strlcat(flags, ", ", sizeof(flags));
       }
-      g_strlcat(flags, fstr[i], 64);
+      g_strlcat(flags, fstr[i], sizeof(flags));
       flags_found = TRUE;
     }
   }
   if (flags[0] == '\0') {
-    g_snprintf (flags, 64, "<None>");
+    g_snprintf (flags, sizeof(flags), "<None>");
   }
 
   if ((tcph->th_have_seglen)&&(tcph->th_seglen!=0)){
@@ -485,13 +476,14 @@ static void flow_graph_dlg_create (void)
 
 	GtkTooltips *tooltips = gtk_tooltips_new();
 
-	flow_graph_dlg_w=window_new(GTK_WINDOW_TOPLEVEL, "Wireshark: Flow Graph");
+	flow_graph_dlg_w = dlg_window_new("Wireshark: Flow Graph");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(flow_graph_dlg_w), TRUE);
 
-	gtk_window_set_default_size(GTK_WINDOW(flow_graph_dlg_w), 350, 150);
+	gtk_window_set_default_size(GTK_WINDOW(flow_graph_dlg_w), 250, 150);
 
 	main_vb = gtk_vbox_new (FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(flow_graph_dlg_w), main_vb);
-	gtk_container_set_border_width (GTK_CONTAINER (main_vb), 12);
+	gtk_container_set_border_width (GTK_CONTAINER (main_vb), 7);
 
 #if 0
 	top_label = gtk_label_new ("Choose packets to include in the graph");
@@ -502,10 +494,10 @@ static void flow_graph_dlg_create (void)
 
 	/*** Packet range frame ***/
 	range_fr = gtk_frame_new("Choose packets");
-	gtk_box_pack_start(GTK_BOX(main_vb), range_fr, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(main_vb), range_fr, FALSE, FALSE, 5);
 
-    range_tb = gtk_table_new(4, 4, FALSE);
-    gtk_container_set_border_width(GTK_CONTAINER(range_tb), 5);
+	range_tb = gtk_table_new(4, 4, FALSE);
+	gtk_container_set_border_width(GTK_CONTAINER(range_tb), 5);
 	gtk_container_add(GTK_CONTAINER(range_fr), range_tb);
 
 	/* Process all packets */
@@ -524,22 +516,21 @@ static void flow_graph_dlg_create (void)
 	gtk_tooltips_set_tip (tooltips, select_displayed_rb,
 		("Process displayed packets"), NULL);
 	g_signal_connect(select_displayed_rb, "toggled", G_CALLBACK(toggle_select_displayed), NULL);
-	gtk_table_attach_defaults(GTK_TABLE(range_tb), select_displayed_rb, 1, 2, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(range_tb), select_displayed_rb, 0, 1, 1, 2);
 	if (type_of_packets == DISPLAYED) {
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(select_displayed_rb),TRUE);
 	}
   	gtk_widget_show(select_displayed_rb);
 
 	gtk_widget_show(range_tb);
-
 	gtk_widget_show(range_fr);
 
 	/*** Flow type frame ***/
 	flow_type_fr = gtk_frame_new("Choose flow type");
-	gtk_box_pack_start(GTK_BOX(main_vb), flow_type_fr, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(main_vb), flow_type_fr, FALSE, FALSE, 5);
 
-    flow_type_tb = gtk_table_new(4, 4, FALSE);
-    gtk_container_set_border_width(GTK_CONTAINER(flow_type_tb), 5);
+	flow_type_tb = gtk_table_new(4, 4, FALSE);
+	gtk_container_set_border_width(GTK_CONTAINER(flow_type_tb), 5);
 	gtk_container_add(GTK_CONTAINER(flow_type_fr), flow_type_tb);
 
 	/* General information */
@@ -558,11 +549,10 @@ static void flow_graph_dlg_create (void)
 	gtk_tooltips_set_tip (tooltips, select_tcp_rb,
 		("Show only TCP packets, with TCP specific information"), NULL);
 	g_signal_connect(select_tcp_rb, "toggled", G_CALLBACK(toggle_select_tcp), NULL);
-	gtk_table_attach_defaults(GTK_TABLE(flow_type_tb), select_tcp_rb, 1, 2, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(flow_type_tb), select_tcp_rb, 0, 1, 1, 2);
 	if (type_of_flow == TCP) {
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(select_tcp_rb),TRUE);
 	}
-
   	gtk_widget_show(select_tcp_rb);
 
 	gtk_widget_show(flow_type_tb);
@@ -570,10 +560,10 @@ static void flow_graph_dlg_create (void)
 
 	/*** Node address type frame ***/
 	node_addr_fr = gtk_frame_new("Choose node address type");
-	gtk_box_pack_start(GTK_BOX(main_vb), node_addr_fr, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(main_vb), node_addr_fr, FALSE, FALSE, 5);
 
-    node_addr_tb = gtk_table_new(4, 4, FALSE);
-    gtk_container_set_border_width(GTK_CONTAINER(node_addr_tb), 5);
+	node_addr_tb = gtk_table_new(4, 4, FALSE);
+	gtk_container_set_border_width(GTK_CONTAINER(node_addr_tb), 5);
 	gtk_container_add(GTK_CONTAINER(node_addr_fr), node_addr_tb);
 
 	/* Source / Dest address */
@@ -592,11 +582,10 @@ static void flow_graph_dlg_create (void)
 	gtk_tooltips_set_tip (tooltips, net_src_dst_rb,
 		("Nodes in the diagram are identified with network source and destination addresses"), NULL);
 	g_signal_connect(net_src_dst_rb, "toggled", G_CALLBACK(toggle_select_netsrcdst), NULL);
-	gtk_table_attach_defaults(GTK_TABLE(node_addr_tb), net_src_dst_rb, 1, 2, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(node_addr_tb), net_src_dst_rb, 0, 1, 1, 2);
 	if (node_addr_type == NET_SRCDST) {
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(net_src_dst_rb),TRUE);
 	}
-
   	gtk_widget_show(net_src_dst_rb);
 
 	gtk_widget_show(node_addr_tb);
@@ -604,7 +593,7 @@ static void flow_graph_dlg_create (void)
 
         /* button row */
 	hbuttonbox = gtk_hbutton_box_new ();
-	gtk_box_pack_start (GTK_BOX (main_vb), hbuttonbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (main_vb), hbuttonbox, FALSE, FALSE, 5);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_SPREAD);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 30);
 
