@@ -1,7 +1,7 @@
 /* follow_udp.c
  * UDP specific routines for following traffic streams
  *
- * $Id: follow_udp.c 24968 2008-04-13 01:54:20Z ulfl $
+ * $Id: follow_udp.c 28062 2009-04-16 00:45:26Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -120,6 +120,7 @@ follow_udp_stream_cb(GtkWidget *w, gpointer data _U_)
 			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
 				      "Error creating filter for this stream.\n"
 				      "A network layer header is needed");
+			g_free(follow_info);
 			return;
 		}
 
@@ -135,8 +136,8 @@ follow_udp_stream_cb(GtkWidget *w, gpointer data _U_)
 
 	/* allocate our new filter. API claims g_malloc terminates program on failure */
 	/* my calc for max alloc needed is really +10 but when did a few extra bytes hurt ? */
-	previous_filter_len = previous_filter?strlen(previous_filter):0;
-	filter_out_filter_len = strlen(follow_filter) + previous_filter_len + 16;
+	previous_filter_len = previous_filter?(int)strlen(previous_filter):0;
+	filter_out_filter_len = (int)strlen(follow_filter) + previous_filter_len + 16;
 	follow_info->filter_out_filter = (gchar *)g_malloc(filter_out_filter_len);
 
 	/* append the negation */
@@ -155,6 +156,9 @@ follow_udp_stream_cb(GtkWidget *w, gpointer data _U_)
 		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
 			      "Can't register udp_follow tap: %s\n",
 			      msg->str);
+		g_free(follow_info->filter_out_filter);
+		g_free(follow_info);
+		g_free(follow_filter);
 		return;
 	}
 
