@@ -1,8 +1,8 @@
 /* profile_dlg.c
  * Dialog box for profiles editing
- * Stig Bjrlykke <stig@bjorlykke.org>, 2008
+ * Stig Bjorlykke <stig@bjorlykke.org>, 2008
  *
- * $Id: profile_dlg.c 25634 2008-06-29 15:51:43Z wmeier $
+ * $Id: profile_dlg.c 27996 2009-04-08 13:41:30Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -154,8 +154,8 @@ copy_profile_list(void)
 static GtkTreeIter *
 fill_list(GtkWidget *main_w)
 {
-  ETH_DIR       *dir;             /* scanned directory */
-  ETH_DIRENT    *file;            /* current file */
+  WS_DIR        *dir;             /* scanned directory */
+  WS_DIRENT     *file;            /* current file */
   GList         *fl_entry;
   profile_def   *profile;
   GtkTreeView   *profile_l;
@@ -204,7 +204,7 @@ fill_list(GtkWidget *main_w)
     ws_dir_close (dir);
   }
 
-  /* Make the current list an the edited list equal */
+  /* Make the current list and the edited list equal */
   copy_profile_list ();
 
   return l_select;
@@ -322,9 +322,8 @@ profile_apply(GtkWidget *main_w, GtkTreeView *profile_l, gboolean destroy)
 	  g_free(pf_dir_path);
 	}
 	profile1->status = PROF_STAT_EXISTS;
-	if (profile1->reference) {
-	  g_free (profile1->reference);
-	}
+
+	g_free (profile1->reference);
 	profile1->reference = g_strdup(profile1->name);
       }
     } else if (profile1->status == PROF_STAT_CHANGED) {
@@ -506,8 +505,7 @@ profile_sel_list_cb(GtkTreeSelection *sel, gpointer data _U_)
     gtk_widget_set_sensitive(copy_bt, sensitivity);
   if (del_bt != NULL)
     gtk_widget_set_sensitive(del_bt, sensitivity);
-  if (name != NULL)
-    g_free(name);
+  g_free(name);
 }
 
 static void
@@ -841,7 +839,7 @@ profile_dialog_new(void)
 }
 
 
-static void 
+static void
 select_profile_cb (GtkWidget *w _U_, gpointer data)
 {
   const gchar *current_profile = get_profile_name ();
@@ -858,8 +856,8 @@ profile_show_popup_cb (GtkWidget *w _U_, GdkEvent *event)
   GdkEventButton *bevent = (GdkEventButton *)event;
   const gchar    *profile_name = get_profile_name ();
   const gchar    *profiles_dir, *name;
-  ETH_DIR        *dir;             /* scanned directory */
-  ETH_DIRENT     *file;            /* current file */
+  WS_DIR         *dir;             /* scanned directory */
+  WS_DIRENT      *file;            /* current file */
   GtkWidget      *menu;
   GtkWidget      *menu_item;
 
@@ -873,7 +871,7 @@ profile_show_popup_cb (GtkWidget *w _U_, GdkEvent *event)
   }
   g_object_set (G_OBJECT(menu_item), "draw-as-radio", TRUE, NULL);
   g_signal_connect (menu_item, "activate", G_CALLBACK(select_profile_cb), g_strdup (DEFAULT_PROFILE));
-  gtk_menu_append (menu, menu_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL(menu), menu_item);
   gtk_widget_show (menu_item);
 
   profiles_dir = get_profiles_dir();
@@ -889,7 +887,7 @@ profile_show_popup_cb (GtkWidget *w _U_, GdkEvent *event)
 	}
 	g_object_set (G_OBJECT(menu_item), "draw-as-radio", TRUE, NULL);
 	g_signal_connect (menu_item, "activate", G_CALLBACK(select_profile_cb), g_strdup (name));
-	gtk_menu_append (menu, menu_item);
+	gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
 	gtk_widget_show (menu_item);
       }
     }
@@ -897,7 +895,7 @@ profile_show_popup_cb (GtkWidget *w _U_, GdkEvent *event)
 
   gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL,
 		  bevent->button, bevent->time);
-    
+
   return TRUE;
 }
 
