@@ -1,7 +1,7 @@
 /*
  *  uat_gui.c
  *
- *  $Id: uat_gui.c 26641 2008-10-31 09:53:56Z stig $
+ *  $Id: uat_gui.c 28108 2009-04-21 16:57:52Z guy $
  *
  *  User Accessible Tables GUI
  *  Mantain an array of user accessible data strucures
@@ -283,15 +283,15 @@ static gboolean uat_dlg_cb(GtkWidget *win _U_, gpointer user_data) {
 		switch(f[colnum].mode) {
 			case PT_TXTMOD_STRING:
 				text = gtk_entry_get_text(GTK_ENTRY(e));
-				len = strlen(text);
+				len = (unsigned) strlen(text);
 				break;
 			case PT_TXTMOD_HEXBYTES: {
 				text = gtk_entry_get_text(GTK_ENTRY(e));
 
-				text = (void*) unhexbytes(text, strlen(text), &len, &err);
+				text = (void*) unhexbytes(text, (guint) strlen(text), &len, &err);
 
 				if (err) {
-					err = ep_strdup_printf("error in field '%s': %s",f[colnum].name,err);
+					err = ep_strdup_printf("error in field '%s': %s",f[colnum].title,err);
 					goto on_failure;
 				}
 
@@ -300,7 +300,7 @@ static gboolean uat_dlg_cb(GtkWidget *win _U_, gpointer user_data) {
 			case PT_TXTMOD_ENUM: {
 				text = *(char**)e;
 				text = text ? text : "";
-				len = strlen(text);
+				len = (unsigned) strlen(text);
 				break;
 			}
 			default:
@@ -311,7 +311,7 @@ static gboolean uat_dlg_cb(GtkWidget *win _U_, gpointer user_data) {
 
 		if (f[colnum].cb.chk) {
 			if (! f[colnum].cb.chk(dd->rec, text, len, f[colnum].cbdata.chk, f[colnum].fld_data, &err)) {
-				err = ep_strdup_printf("error in field '%s': %s",f[colnum].name,err);
+				err = ep_strdup_printf("error in column '%s': %s",f[colnum].title,err);
 				goto on_failure;
 			}
 		}
@@ -429,17 +429,27 @@ static void uat_edit_dialog(uat_t* uat, gint row) {
 	gtk_table_set_row_spacings(GTK_TABLE(main_tb), 5);
 	gtk_table_set_col_spacings(GTK_TABLE(main_tb), 10);
 
+	bbox = dlg_button_row_new(GTK_STOCK_CANCEL,GTK_STOCK_OK, NULL);
+	gtk_box_pack_end(GTK_BOX(main_vb), bbox, FALSE, FALSE, 0);
+
+	bt_ok = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_OK);
+	g_signal_connect(bt_ok, "clicked", G_CALLBACK(uat_dlg_cb), dd);
+
+	bt_cancel = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CANCEL);
+	g_signal_connect(bt_cancel, "clicked", G_CALLBACK(uat_cancel_dlg_cb), dd);
+	window_set_cancel_button(win, bt_cancel, NULL);
+
 	for ( colnum = 0; colnum < uat->ncols; colnum++ ) {
 		GtkWidget *entry, *label, *event_box;
 		char* text = fld_tostr(dd->rec,&(f[colnum]));
 
 		event_box = gtk_event_box_new();
 
-		label = gtk_label_new(f[colnum].name);
+		label = gtk_label_new(ep_strdup_printf("%s:", f[colnum].title));
 		if (f[colnum].desc != NULL)
 			gtk_tooltips_set_tip(tooltips, event_box, f[colnum].desc, NULL);
 
-		gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+		gtk_misc_set_alignment(GTK_MISC(label), 1.0f, 0.5f);
 		gtk_table_attach_defaults(GTK_TABLE(main_tb), event_box, 0, 1, colnum+1, colnum + 2);
 		gtk_container_add(GTK_CONTAINER(event_box), label);
 
@@ -452,6 +462,7 @@ static void uat_edit_dialog(uat_t* uat, gint row) {
 				if (! dd->is_new) {
 					gtk_entry_set_text(GTK_ENTRY(entry),text);
 				}
+				dlg_set_activate(entry, bt_ok);
 				break;
 			}
 			case PT_TXTMOD_ENUM: {
@@ -502,16 +513,7 @@ static void uat_edit_dialog(uat_t* uat, gint row) {
 		}
 	}
 	
-	bbox = dlg_button_row_new(GTK_STOCK_CANCEL,GTK_STOCK_OK, NULL);
-	gtk_box_pack_end(GTK_BOX(main_vb), bbox, FALSE, FALSE, 0);
-
-	bt_ok = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_OK);
-	g_signal_connect(bt_ok, "clicked", G_CALLBACK(uat_dlg_cb), dd);
-
-	bt_cancel = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CANCEL);
-	g_signal_connect(bt_cancel, "clicked", G_CALLBACK(uat_cancel_dlg_cb), dd);
-	window_set_cancel_button(win, bt_cancel, NULL);
-
+	gtk_widget_grab_default(bt_ok);
 	gtk_widget_show_all(win);
 }
 
@@ -576,12 +578,12 @@ static void uat_del_dlg(uat_t* uat, int idx) {
 		GtkWidget *label;
         	char* text = fld_tostr(rec,&(f[colnum]));
 
-		label = gtk_label_new(f[colnum].name);
-		gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+		label = gtk_label_new(ep_strdup_printf("%s:", f[colnum].title));
+		gtk_misc_set_alignment(GTK_MISC(label), 1.0f, 0.5f);
 		gtk_table_attach_defaults(GTK_TABLE(main_tb), label, 0, 1, colnum+1, colnum + 2);
 		
 		label = gtk_label_new(text);
-		gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+		gtk_misc_set_alignment(GTK_MISC(label), 1.0f, 0.5f);
 		gtk_table_attach_defaults(GTK_TABLE(main_tb), label, 1, 2, colnum+1, colnum + 2);
 	}
 
@@ -634,7 +636,7 @@ static gboolean uat_window_delete_event_cb(GtkWindow *w _U_, GdkEvent* e _U_, gp
 		gtk_widget_destroy(uat->rep->window);
 
 		uat->rep = NULL;
-		if (rep) g_free(rep);
+		g_free(rep);
 	}
 	return TRUE;
 }
@@ -696,8 +698,6 @@ static void uat_cancel_cb(GtkWidget *button _U_, gpointer u) {
 static void uat_apply_cb(GtkButton *button _U_, gpointer u) {
 	uat_t* uat = u;
 
-	uat_window_delete_event_cb(NULL,NULL,uat);
-
 	if (uat->changed && cfile.state == FILE_READ_DONE)
 		cf_reload(&cfile);
 }
@@ -856,7 +856,7 @@ static GtkWidget* uat_window(void* u) {
 	gtk_box_pack_start(GTK_BOX(hbox), rep->scrolledwindow, TRUE, TRUE, 0);
 
 	for ( colnum = 0; colnum < uat->ncols; colnum++ ) {
-		gtk_clist_set_column_title(GTK_CLIST(rep->clist), colnum, f[colnum].name);
+		gtk_clist_set_column_title(GTK_CLIST(rep->clist), colnum, f[colnum].title);
 		gtk_clist_set_column_auto_resize(GTK_CLIST(rep->clist), colnum, TRUE);
 	}
 
