@@ -2,7 +2,7 @@
  * Routines for Dynamic Service Delete Response dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-dsdrsp.c 32662 2010-05-04 21:44:03Z gerald $
+ * $Id: packet-dsdrsp.c 23088 2007-10-07 23:46:44Z richardv $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -67,7 +67,7 @@ dissect_dsdrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       col_clear (pinfo->cinfo, COL_INFO);
       col_add_fstr (pinfo->cinfo, COL_INFO,
 		    "Dynamic Service Delete Response Tran id = %u (%s)",
-		    tranid, val_to_str (confcode, docsis_conf_code, "%d"));
+		    tranid, val_to_str (confcode, docsis_conf_code, "%s"));
     }
 
   if (tree)
