@@ -6,7 +6,7 @@
  *
  * Author: Stephen Croll <croll@mobilemetrics.net>
  *
- * $Id: packet-wimaxasncp.c 25530 2008-06-23 13:02:50Z martinm $
+ * $Id: packet-wimaxasncp.c 27062 2008-12-19 17:39:52Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1468,18 +1468,18 @@ static void wimaxasncp_dissect_tlv_value(
         /* Add code and type to info column */
         if (check_col(pinfo->cinfo, COL_INFO))
         {
-            col_append_fstr(pinfo->cinfo, COL_INFO, " [");
-            col_append_fstr(pinfo->cinfo, COL_INFO,
+            col_append_str(pinfo->cinfo, COL_INFO, " [");
+            col_append_str(pinfo->cinfo, COL_INFO,
                             val_to_str(eap_code, eap_code_vals, "Unknown code (0x%02X)"));
 
             if (eap_code == EAP_REQUEST || eap_code == EAP_RESPONSE)
             {
-                col_append_fstr(pinfo->cinfo, COL_INFO, ", ");
-                col_append_fstr(pinfo->cinfo, COL_INFO,
+                col_append_str(pinfo->cinfo, COL_INFO, ", ");
+                col_append_str(pinfo->cinfo, COL_INFO,
                                 val_to_str(eap_type, eap_type_vals, "Unknown type (0x%02X)"));
             }
 
-            col_append_fstr(pinfo->cinfo, COL_INFO, "]");
+            col_append_str(pinfo->cinfo, COL_INFO, "]");
         }
 
 
