@@ -1,7 +1,7 @@
 /* tap-iousers.c
  * iostat   2003 Ronnie Sahlberg
  *
- * $Id: tap-iousers.c 26093 2008-08-26 02:38:57Z wmeier $
+ * $Id: tap-iousers.c 28425 2009-05-20 15:50:40Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -253,7 +253,7 @@ static int
 iousers_ip_packet(void *arg, packet_info *pinfo, epan_dissect_t *edt _U_, const void *vip)
 {
 	io_users_t *iu=arg;
-	const e_ip *iph=vip;
+	const ws_ip *iph=vip;
 	const address *addr1, *addr2;
 	io_users_item_t *iui;
 
