@@ -32,7 +32,7 @@
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
-* $Id: erf.h 24628 2008-03-14 17:47:53Z gerald $
+* $Id: erf.h 26287 2008-09-29 16:20:24Z etxrab $
 */
 
 #ifndef __W_ERF_H__
@@ -59,6 +59,9 @@
 #define ERF_TYPE_COLOR_MC_HDLC_POS  17
 #define ERF_TYPE_AAL2               18
 #define ERF_TYPE_INFINIBAND         21
+#define ERF_TYPE_IPV4		    				22
+#define ERF_TYPE_IPV6		    				23
+#define ERF_TYPE_RAW_LINK	    			24
 
 #define ERF_TYPE_PAD                48
 
